# openapi-client
# Developer Support and Feedback
* Clio takes the availability and stability of our API seriously; please report any **degradations** or **breakages** to Clio's API Support team at [api@clio.com](mailto:api@clio.com).
* For business and partnership inquiries, contact our API Partnerships team at [api.partnerships@clio.com](mailto:api.partnerships@clio.com).
* For best practices and tips from the Clio development community, join the conversation in the [Clio Developer Slack Channel](https://join.slack.com/t/clio-public/shared_invite/zt-1bd5nfbiv-WloZR3ZjepoUTv28SI1ezw).

A community-driven [Clio Developers Stack Overflow Group](https://stackoverflow.com/questions/tagged/clio-api) also exists where you can connect and ask questions from other Clio API users.
# Getting Started
> **Note:** The API is available in four distinct data regions: Australia (au.app.clio.com), Canada (ca.app.clio.com), EU (eu.app.clio.com) and US (app.clio.com).
>
> Likewise, the developer portal is available at region-specific links for the [Australia](https://au.developers.clio.com), [Canada](https://ca.developers.clio.com), [EU](https://eu.developers.clio.com), and [US](https://developers.clio.com) regions.
>
> This document assumes the US region is being used (app.clio.com). If you're building in one of the other regions, you should adapt the links and examples as necessary.

To start building on the Clio API, you’ll need a Clio account – you can review our [Developer Handbook](https://docs.developers.clio.com/) and follow the steps to sign up for an account.

Once you have an account, you can [create a developer application](https://docs.developers.clio.com/api-docs/applications) from the [Developer Portal](https://developers.clio.com) and start building!
# Authorization with OAuth 2.0
See our [Authorization documentation →](https://docs.developers.clio.com/api-docs/authorization)
# Permissions
See our [Permissions documentation →](https://docs.developers.clio.com/api-docs/permissions)
# Fields
See our [Fields documentation →](https://docs.developers.clio.com/api-docs/fields)
# Rate Limiting
See our [Rate Limits documentation →](https://docs.developers.clio.com/api-docs/rate-limits)
# Paging
See our [Pagination documentation →](https://docs.developers.clio.com/api-docs/paging)
# ETags
See our [ETags documentation →](https://docs.developers.clio.com/api-docs/etags)
# Minor Versions
API v4 supports multiple minor versions. Versions are of the form '4.X.Y'. To request a specific version, you can use an `X-API-VERSION` header in your request, with the header value set to the API version you're requesting. If this header is omitted, it will be treated as a request for the default API version. If the header is present but invalid, it will return a `410 Gone` response. If the header is present and valid, but it is no longer supported, it will return a `410 Gone` response.

An `X-API-VERSION` will be included in all successful responses, with the value being set to the API version used.

You can find our [API Versioning Policy and Guidelines](https://docs.developers.clio.com/api-docs/api-versioning-policy) in our documentation hub.

The [API Changelog](https://docs.developers.clio.com/api-docs/api-changelog) explains each version's changes in further detail.
- 4.0.4

  Update `quantity` field to return values in seconds rather than hours for Activities

- 4.0.5

  * Remove `matter_balances` field from Bills
  * Standardize status/state enum values
  * Add a Document association to completed DocumentAutomations
  * Add rate visibility handling for Activity's price and total

- 4.0.6

  Remove `document_versions` collection field from Documents

- 4.0.7

  Change secure link format

- 4.0.8

  * `Activity` hours are redacted in the response based on the activity hours visibility setting for the user
  * Add `quantity_redacted` field to activities

- 4.0.9

  **This is the default version**

  Contacts are filtered and redacted in the response based on the new 'Contacts Visibility' user permission setting.

- 4.0.10

  Fixed validation of `type` query parameter when querying Notes




This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v4
- Package version: 1.0.0
- Generator version: 7.9.0
- Build package: org.openapitools.codegen.languages.PythonPydanticV1ClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://app.clio.com/api/v4
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://app.clio.com/api/v4"
)



# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.ActivitiesApi(api_client)
    x_api_version = 'x_api_version_example' # str | The [API minor version](#section/Minor-Versions). Default: latest version. (optional)
    fields = 'fields_example' # str | The fields to be returned. See response samples for what fields are available. For more information see the [fields section](#section/Fields). (optional)
    activity_create_request = openapi_client.ActivityCreateRequest() # ActivityCreateRequest | Request Body for Activities (optional)

    try:
        # Create a new Activity
        api_response = api_instance.activity_create(x_api_version=x_api_version, fields=fields, activity_create_request=activity_create_request)
        print("The response of ActivitiesApi->activity_create:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ActivitiesApi->activity_create: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://app.clio.com/api/v4*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActivitiesApi* | [**activity_create**](docs/ActivitiesApi.md#activity_create) | **POST** /activities.json | Create a new Activity
*ActivitiesApi* | [**activity_destroy**](docs/ActivitiesApi.md#activity_destroy) | **DELETE** /activities/{id}.json | Delete a single Activity
*ActivitiesApi* | [**activity_index**](docs/ActivitiesApi.md#activity_index) | **GET** /activities.json | Return the data for all Activities
*ActivitiesApi* | [**activity_show**](docs/ActivitiesApi.md#activity_show) | **GET** /activities/{id}.json | Return the data for a single Activity
*ActivitiesApi* | [**activity_update**](docs/ActivitiesApi.md#activity_update) | **PATCH** /activities/{id}.json | Update a single Activity
*ActivityDescriptionsApi* | [**activity_description_create**](docs/ActivityDescriptionsApi.md#activity_description_create) | **POST** /activity_descriptions.json | Create a new ActivityDescription
*ActivityDescriptionsApi* | [**activity_description_destroy**](docs/ActivityDescriptionsApi.md#activity_description_destroy) | **DELETE** /activity_descriptions/{id}.json | Delete a single ActivityDescription
*ActivityDescriptionsApi* | [**activity_description_index**](docs/ActivityDescriptionsApi.md#activity_description_index) | **GET** /activity_descriptions.json | Return the data for all ActivityDescriptions
*ActivityDescriptionsApi* | [**activity_description_show**](docs/ActivityDescriptionsApi.md#activity_description_show) | **GET** /activity_descriptions/{id}.json | Return the data for a single ActivityDescription
*ActivityDescriptionsApi* | [**activity_description_update**](docs/ActivityDescriptionsApi.md#activity_description_update) | **PATCH** /activity_descriptions/{id}.json | Update a single ActivityDescription
*ActivityRatesApi* | [**activity_rate_create**](docs/ActivityRatesApi.md#activity_rate_create) | **POST** /activity_rates.json | Create a new ActivityRate
*ActivityRatesApi* | [**activity_rate_destroy**](docs/ActivityRatesApi.md#activity_rate_destroy) | **DELETE** /activity_rates/{id}.json | Delete a single ActivityRate
*ActivityRatesApi* | [**activity_rate_index**](docs/ActivityRatesApi.md#activity_rate_index) | **GET** /activity_rates.json | Return the data for all ActivityRates
*ActivityRatesApi* | [**activity_rate_show**](docs/ActivityRatesApi.md#activity_rate_show) | **GET** /activity_rates/{id}.json | Return the data for a single ActivityRate
*ActivityRatesApi* | [**activity_rate_update**](docs/ActivityRatesApi.md#activity_rate_update) | **PATCH** /activity_rates/{id}.json | Update a single ActivityRate
*AllocationsApi* | [**allocation_index**](docs/AllocationsApi.md#allocation_index) | **GET** /allocations.json | Return the data for all Allocations
*AllocationsApi* | [**allocation_show**](docs/AllocationsApi.md#allocation_show) | **GET** /allocations/{id}.json | Return the data for a single Allocation
*BankAccountsApi* | [**bank_account_create**](docs/BankAccountsApi.md#bank_account_create) | **POST** /bank_accounts.json | Create a new BankAccount
*BankAccountsApi* | [**bank_account_destroy**](docs/BankAccountsApi.md#bank_account_destroy) | **DELETE** /bank_accounts/{id}.json | Delete a single BankAccount
*BankAccountsApi* | [**bank_account_index**](docs/BankAccountsApi.md#bank_account_index) | **GET** /bank_accounts.json | Return the data for all BankAccounts
*BankAccountsApi* | [**bank_account_show**](docs/BankAccountsApi.md#bank_account_show) | **GET** /bank_accounts/{id}.json | Return the data for a single BankAccount
*BankAccountsApi* | [**bank_account_update**](docs/BankAccountsApi.md#bank_account_update) | **PATCH** /bank_accounts/{id}.json | Update a single BankAccount
*BankTransactionsApi* | [**bank_transaction_index**](docs/BankTransactionsApi.md#bank_transaction_index) | **GET** /bank_transactions.json | Return the data for all BankTransactions
*BankTransactionsApi* | [**bank_transaction_show**](docs/BankTransactionsApi.md#bank_transaction_show) | **GET** /bank_transactions/{id}.json | Return the data for a single BankTransaction
*BankTransfersApi* | [**bank_transfer_show**](docs/BankTransfersApi.md#bank_transfer_show) | **GET** /bank_transfers/{id}.json | Return the data for a single BankTransfer
*BillThemesApi* | [**bill_theme_index**](docs/BillThemesApi.md#bill_theme_index) | **GET** /bill_themes.json | Return the data for all BillThemes
*BillThemesApi* | [**bill_theme_update**](docs/BillThemesApi.md#bill_theme_update) | **PATCH** /bill_themes/{id}.json | Update a single BillTheme
*BillableClientsApi* | [**billable_client_index**](docs/BillableClientsApi.md#billable_client_index) | **GET** /billable_clients.json | Return the data for all BillableClients
*BillableMattersApi* | [**billable_matter_ids**](docs/BillableMattersApi.md#billable_matter_ids) | **GET** /billable_matters/ids.json | Returns the unique identifiers of all BillableMatter
*BillableMattersApi* | [**billable_matter_index**](docs/BillableMattersApi.md#billable_matter_index) | **GET** /billable_matters.json | Return the data for all BillableMatters
*BillingSettingsApi* | [**billing_setting_show**](docs/BillingSettingsApi.md#billing_setting_show) | **GET** /settings/billing.json | Return the billing settings
*BillsApi* | [**bill_destroy**](docs/BillsApi.md#bill_destroy) | **DELETE** /bills/{id}.json | Delete or void a Bill
*BillsApi* | [**bill_index**](docs/BillsApi.md#bill_index) | **GET** /bills.json | Return the data for all Bills
*BillsApi* | [**bill_preview**](docs/BillsApi.md#bill_preview) | **GET** /bills/{id}/preview.json | Returns the pre-rendered html for the Bill
*BillsApi* | [**bill_show**](docs/BillsApi.md#bill_show) | **GET** /bills/{id}.json | Return the data for a single Bill
*BillsApi* | [**bill_update**](docs/BillsApi.md#bill_update) | **PATCH** /bills/{id}.json | Update a single Bill
*CalendarEntriesApi* | [**calendar_entry_create**](docs/CalendarEntriesApi.md#calendar_entry_create) | **POST** /calendar_entries.json | Create a new CalendarEntry
*CalendarEntriesApi* | [**calendar_entry_destroy**](docs/CalendarEntriesApi.md#calendar_entry_destroy) | **DELETE** /calendar_entries/{id}.json | Delete a single CalendarEntry
*CalendarEntriesApi* | [**calendar_entry_index**](docs/CalendarEntriesApi.md#calendar_entry_index) | **GET** /calendar_entries.json | Return the data for all CalendarEntries
*CalendarEntriesApi* | [**calendar_entry_show**](docs/CalendarEntriesApi.md#calendar_entry_show) | **GET** /calendar_entries/{id}.json | Return the data for a single CalendarEntry
*CalendarEntriesApi* | [**calendar_entry_update**](docs/CalendarEntriesApi.md#calendar_entry_update) | **PATCH** /calendar_entries/{id}.json | Update a single CalendarEntry
*CalendarEntryEventTypesApi* | [**calendar_entry_event_type_create**](docs/CalendarEntryEventTypesApi.md#calendar_entry_event_type_create) | **POST** /calendar_entry_event_types.json | Create a new calendar entry event type
*CalendarEntryEventTypesApi* | [**calendar_entry_event_type_destroy**](docs/CalendarEntryEventTypesApi.md#calendar_entry_event_type_destroy) | **DELETE** /calendar_entry_event_types/{id}.json | Delete a single calendar entry event type
*CalendarEntryEventTypesApi* | [**calendar_entry_event_type_index**](docs/CalendarEntryEventTypesApi.md#calendar_entry_event_type_index) | **GET** /calendar_entry_event_types.json | Return the data for all calendar entry event types
*CalendarEntryEventTypesApi* | [**calendar_entry_event_type_show**](docs/CalendarEntryEventTypesApi.md#calendar_entry_event_type_show) | **GET** /calendar_entry_event_types/{id}.json | Return the data for a single calendar entry event type
*CalendarEntryEventTypesApi* | [**calendar_entry_event_type_update**](docs/CalendarEntryEventTypesApi.md#calendar_entry_event_type_update) | **PATCH** /calendar_entry_event_types/{id}.json | Update a single calendar entry event type
*CalendarVisibilitiesApi* | [**calendar_visibility_index**](docs/CalendarVisibilitiesApi.md#calendar_visibility_index) | **GET** /task_calendars.json | Return the data for all CalendarVisibilities
*CalendarVisibilitiesApi* | [**calendar_visibility_show**](docs/CalendarVisibilitiesApi.md#calendar_visibility_show) | **GET** /task_calendars/{id}.json | Return the data for a single CalendarVisibility
*CalendarVisibilitiesApi* | [**calendar_visibility_update**](docs/CalendarVisibilitiesApi.md#calendar_visibility_update) | **PATCH** /task_calendars/{id}.json | Update a single CalendarVisibility
*CalendarsApi* | [**calendar_create**](docs/CalendarsApi.md#calendar_create) | **POST** /calendars.json | Create a new Calendar
*CalendarsApi* | [**calendar_destroy**](docs/CalendarsApi.md#calendar_destroy) | **DELETE** /calendars/{id}.json | Delete a single Calendar
*CalendarsApi* | [**calendar_index**](docs/CalendarsApi.md#calendar_index) | **GET** /calendars.json | Return the data for all Calendars
*CalendarsApi* | [**calendar_show**](docs/CalendarsApi.md#calendar_show) | **GET** /calendars/{id}.json | Return the data for a single Calendar
*CalendarsApi* | [**calendar_update**](docs/CalendarsApi.md#calendar_update) | **PATCH** /calendars/{id}.json | Update a single Calendar
*CivilCertificatedRatesApi* | [**lauk_civil_certificated_rate_index**](docs/CivilCertificatedRatesApi.md#lauk_civil_certificated_rate_index) | **GET** /lauk_civil_certificated_rates.json | List Civil Certificated Rates
*CivilControlledRatesApi* | [**lauk_civil_controlled_rate_index**](docs/CivilControlledRatesApi.md#lauk_civil_controlled_rate_index) | **GET** /lauk_civil_controlled_rates.json | List Civil Controlled Rates
*ClientsApi* | [**client_show**](docs/ClientsApi.md#client_show) | **GET** /matters/{matter_id}/client.json | Return the client data for a single matter
*ClioPaymentsLinksApi* | [**clio_payments_link_create**](docs/ClioPaymentsLinksApi.md#clio_payments_link_create) | **POST** /clio_payments/links.json | Create a new ClioPaymentsLink
*ClioPaymentsLinksApi* | [**clio_payments_link_index**](docs/ClioPaymentsLinksApi.md#clio_payments_link_index) | **GET** /clio_payments/links.json | Return the data for all ClioPaymentsLinks
*ClioPaymentsLinksApi* | [**clio_payments_link_show**](docs/ClioPaymentsLinksApi.md#clio_payments_link_show) | **GET** /clio_payments/links/{id}.json | Return the data for a single ClioPaymentsLink
*ClioPaymentsLinksApi* | [**clio_payments_link_update**](docs/ClioPaymentsLinksApi.md#clio_payments_link_update) | **PATCH** /clio_payments/links/{id}.json | Update a single ClioPaymentsLink
*ClioPaymentsPaymentsApi* | [**clio_payments_payment_index**](docs/ClioPaymentsPaymentsApi.md#clio_payments_payment_index) | **GET** /clio_payments/payments.json | Return the data for all ClioPaymentsPayments
*ClioPaymentsPaymentsApi* | [**clio_payments_payment_show**](docs/ClioPaymentsPaymentsApi.md#clio_payments_payment_show) | **GET** /clio_payments/payments/{id}.json | Return the data for a single ClioPaymentsPayment
*CommentsApi* | [**comment_create**](docs/CommentsApi.md#comment_create) | **POST** /comments.json | Create a new Comment
*CommentsApi* | [**comment_destroy**](docs/CommentsApi.md#comment_destroy) | **DELETE** /comments/{id}.json | Delete a single Comment
*CommentsApi* | [**comment_index**](docs/CommentsApi.md#comment_index) | **GET** /comments.json | Return the data for all Comments
*CommentsApi* | [**comment_show**](docs/CommentsApi.md#comment_show) | **GET** /comments/{id}.json | Return the data for a single Comment
*CommentsApi* | [**comment_update**](docs/CommentsApi.md#comment_update) | **PATCH** /comments/{id}.json | Update a single Comment
*CommunicationsApi* | [**communication_create**](docs/CommunicationsApi.md#communication_create) | **POST** /communications.json | Create a new Communication
*CommunicationsApi* | [**communication_destroy**](docs/CommunicationsApi.md#communication_destroy) | **DELETE** /communications/{id}.json | Delete a single Communication
*CommunicationsApi* | [**communication_index**](docs/CommunicationsApi.md#communication_index) | **GET** /communications.json | Return the data for all Communications
*CommunicationsApi* | [**communication_show**](docs/CommunicationsApi.md#communication_show) | **GET** /communications/{id}.json | Return the data for a single Communication
*CommunicationsApi* | [**communication_update**](docs/CommunicationsApi.md#communication_update) | **PATCH** /communications/{id}.json | Update a single Communication
*ContactsApi* | [**contact_create**](docs/ContactsApi.md#contact_create) | **POST** /contacts.json | Create a new Contact
*ContactsApi* | [**contact_destroy**](docs/ContactsApi.md#contact_destroy) | **DELETE** /contacts/{id}.json | Delete a single Contact
*ContactsApi* | [**contact_index**](docs/ContactsApi.md#contact_index) | **GET** /contacts.json | Return the data for all Contacts
*ContactsApi* | [**contact_show**](docs/ContactsApi.md#contact_show) | **GET** /contacts/{id}.json | Return the data for a single Contact
*ContactsApi* | [**contact_update**](docs/ContactsApi.md#contact_update) | **PATCH** /contacts/{id}.json | Update a single Contact
*ConversationMessagesApi* | [**conversation_message_create**](docs/ConversationMessagesApi.md#conversation_message_create) | **POST** /conversation_messages.json | Create a new ConversationMessage
*ConversationMessagesApi* | [**conversation_message_index**](docs/ConversationMessagesApi.md#conversation_message_index) | **GET** /conversation_messages.json | Return the data for all ConversationMessages
*ConversationMessagesApi* | [**conversation_message_show**](docs/ConversationMessagesApi.md#conversation_message_show) | **GET** /conversation_messages/{id}.json | Return the data for a single ConversationMessage
*ConversationsApi* | [**conversation_index**](docs/ConversationsApi.md#conversation_index) | **GET** /conversations.json | Return the data for all Conversations
*ConversationsApi* | [**conversation_show**](docs/ConversationsApi.md#conversation_show) | **GET** /conversations/{id}.json | Return the data for a single Conversation
*ConversationsApi* | [**conversation_update**](docs/ConversationsApi.md#conversation_update) | **PATCH** /conversations/{id}.json | Update a single Conversation
*CreditMemosApi* | [**credit_memo_index**](docs/CreditMemosApi.md#credit_memo_index) | **GET** /credit_memos.json | Return the data for all CreditMemos
*CreditMemosApi* | [**credit_memo_show**](docs/CreditMemosApi.md#credit_memo_show) | **GET** /credit_memos/{id}.json | Return the data for a single CreditMemo
*CriminalControlledRatesApi* | [**lauk_criminal_controlled_rate_index**](docs/CriminalControlledRatesApi.md#lauk_criminal_controlled_rate_index) | **GET** /lauk_criminal_controlled_rates.json | List Criminal Controlled Rates
*CurrenciesApi* | [**currency_index**](docs/CurrenciesApi.md#currency_index) | **GET** /currencies.json | Return the data for all Currencies
*CustomActionsApi* | [**custom_action_create**](docs/CustomActionsApi.md#custom_action_create) | **POST** /custom_actions.json | Create a new CustomAction
*CustomActionsApi* | [**custom_action_destroy**](docs/CustomActionsApi.md#custom_action_destroy) | **DELETE** /custom_actions/{id}.json | Delete a single CustomAction
*CustomActionsApi* | [**custom_action_index**](docs/CustomActionsApi.md#custom_action_index) | **GET** /custom_actions.json | Return the data for all CustomActions
*CustomActionsApi* | [**custom_action_show**](docs/CustomActionsApi.md#custom_action_show) | **GET** /custom_actions/{id}.json | Return the data for a single CustomAction
*CustomActionsApi* | [**custom_action_update**](docs/CustomActionsApi.md#custom_action_update) | **PATCH** /custom_actions/{id}.json | Update a single CustomAction
*CustomFieldSetsApi* | [**custom_field_set_create**](docs/CustomFieldSetsApi.md#custom_field_set_create) | **POST** /custom_field_sets.json | Create a new CustomFieldSet
*CustomFieldSetsApi* | [**custom_field_set_destroy**](docs/CustomFieldSetsApi.md#custom_field_set_destroy) | **DELETE** /custom_field_sets/{id}.json | Delete a single CustomFieldSet
*CustomFieldSetsApi* | [**custom_field_set_index**](docs/CustomFieldSetsApi.md#custom_field_set_index) | **GET** /custom_field_sets.json | Return the data for all CustomFieldSets
*CustomFieldSetsApi* | [**custom_field_set_show**](docs/CustomFieldSetsApi.md#custom_field_set_show) | **GET** /custom_field_sets/{id}.json | Return the data for a single CustomFieldSet
*CustomFieldSetsApi* | [**custom_field_set_update**](docs/CustomFieldSetsApi.md#custom_field_set_update) | **PATCH** /custom_field_sets/{id}.json | Update a single CustomFieldSet
*CustomFieldsApi* | [**custom_field_create**](docs/CustomFieldsApi.md#custom_field_create) | **POST** /custom_fields.json | Create a new CustomField
*CustomFieldsApi* | [**custom_field_destroy**](docs/CustomFieldsApi.md#custom_field_destroy) | **DELETE** /custom_fields/{id}.json | Delete a single CustomField
*CustomFieldsApi* | [**custom_field_index**](docs/CustomFieldsApi.md#custom_field_index) | **GET** /custom_fields.json | Return the data for all CustomFields
*CustomFieldsApi* | [**custom_field_show**](docs/CustomFieldsApi.md#custom_field_show) | **GET** /custom_fields/{id}.json | Return the data for a single CustomField
*CustomFieldsApi* | [**custom_field_update**](docs/CustomFieldsApi.md#custom_field_update) | **PATCH** /custom_fields/{id}.json | Update a single CustomField
*DamagesApi* | [**damage_create**](docs/DamagesApi.md#damage_create) | **POST** /damages.json | Creating a Damage
*DamagesApi* | [**damage_destroy**](docs/DamagesApi.md#damage_destroy) | **DELETE** /damages/{id}.json | Deleting a Damage
*DamagesApi* | [**damage_index**](docs/DamagesApi.md#damage_index) | **GET** /damages.json | Return the data for all Damages
*DamagesApi* | [**damage_show**](docs/DamagesApi.md#damage_show) | **GET** /damages/{id}.json | Return a specific Damage
*DamagesApi* | [**damage_update**](docs/DamagesApi.md#damage_update) | **PATCH** /damages/{id}.json | Updating a Damage
*DocumentArchivesApi* | [**document_archive_create**](docs/DocumentArchivesApi.md#document_archive_create) | **POST** /document_archives.json | Create a new DocumentArchive
*DocumentArchivesApi* | [**document_archive_download**](docs/DocumentArchivesApi.md#document_archive_download) | **GET** /document_archives/{id}/download.json | Download the DocumentArchive
*DocumentArchivesApi* | [**document_archive_show**](docs/DocumentArchivesApi.md#document_archive_show) | **GET** /document_archives/{id}.json | Return the data for a single DocumentArchive
*DocumentAutomationsApi* | [**document_automation_create**](docs/DocumentAutomationsApi.md#document_automation_create) | **POST** /document_automations.json | Create a new DocumentAutomation
*DocumentAutomationsApi* | [**document_automation_index**](docs/DocumentAutomationsApi.md#document_automation_index) | **GET** /document_automations.json | Return the data for all DocumentAutomations
*DocumentAutomationsApi* | [**document_automation_show**](docs/DocumentAutomationsApi.md#document_automation_show) | **GET** /document_automations/{id}.json | Return the data for a single DocumentAutomation
*DocumentCategoriesApi* | [**document_category_create**](docs/DocumentCategoriesApi.md#document_category_create) | **POST** /document_categories.json | Create a new DocumentCategory
*DocumentCategoriesApi* | [**document_category_destroy**](docs/DocumentCategoriesApi.md#document_category_destroy) | **DELETE** /document_categories/{id}.json | Delete a single DocumentCategory
*DocumentCategoriesApi* | [**document_category_index**](docs/DocumentCategoriesApi.md#document_category_index) | **GET** /document_categories.json | Return the data for all DocumentCategories
*DocumentCategoriesApi* | [**document_category_show**](docs/DocumentCategoriesApi.md#document_category_show) | **GET** /document_categories/{id}.json | Return the data for a single DocumentCategory
*DocumentCategoriesApi* | [**document_category_update**](docs/DocumentCategoriesApi.md#document_category_update) | **PATCH** /document_categories/{id}.json | Update a single DocumentCategory
*DocumentTemplatesApi* | [**document_template_create**](docs/DocumentTemplatesApi.md#document_template_create) | **POST** /document_templates.json | Create a new DocumentTemplate
*DocumentTemplatesApi* | [**document_template_destroy**](docs/DocumentTemplatesApi.md#document_template_destroy) | **DELETE** /document_templates/{id}.json | Delete a single DocumentTemplate
*DocumentTemplatesApi* | [**document_template_download**](docs/DocumentTemplatesApi.md#document_template_download) | **GET** /document_templates/{id}/download.json | Get the contents of the DocumentTemplate
*DocumentTemplatesApi* | [**document_template_index**](docs/DocumentTemplatesApi.md#document_template_index) | **GET** /document_templates.json | Return the data for all DocumentTemplates
*DocumentTemplatesApi* | [**document_template_show**](docs/DocumentTemplatesApi.md#document_template_show) | **GET** /document_templates/{id}.json | Return the data for a single DocumentTemplate
*DocumentTemplatesApi* | [**document_template_update**](docs/DocumentTemplatesApi.md#document_template_update) | **PATCH** /document_templates/{id}.json | Update a single DocumentTemplate
*DocumentVersionsApi* | [**document_version_index**](docs/DocumentVersionsApi.md#document_version_index) | **GET** /documents/{id}/versions.json | Return the data for all DocumentVersions
*DocumentsApi* | [**document_copy**](docs/DocumentsApi.md#document_copy) | **POST** /documents/{id}/copy.json | Copy a Document
*DocumentsApi* | [**document_create**](docs/DocumentsApi.md#document_create) | **POST** /documents.json | Create a new Document
*DocumentsApi* | [**document_destroy**](docs/DocumentsApi.md#document_destroy) | **DELETE** /documents/{id}.json | Delete a single Document
*DocumentsApi* | [**document_download**](docs/DocumentsApi.md#document_download) | **GET** /documents/{id}/download.json | Download the Document
*DocumentsApi* | [**document_index**](docs/DocumentsApi.md#document_index) | **GET** /documents.json | Return the data for all Documents
*DocumentsApi* | [**document_show**](docs/DocumentsApi.md#document_show) | **GET** /documents/{id}.json | Return the data for a single Document
*DocumentsApi* | [**document_update**](docs/DocumentsApi.md#document_update) | **PATCH** /documents/{id}.json | Update a single Document
*EventMetricsApi* | [**event_metrics_index**](docs/EventMetricsApi.md#event_metrics_index) | **GET** /internal_notifications/event_metrics.json | Unread in-app notification events
*ExpenseCategoriesApi* | [**expense_category_create**](docs/ExpenseCategoriesApi.md#expense_category_create) | **POST** /expense_categories.json | Create a new ExpenseCategory
*ExpenseCategoriesApi* | [**expense_category_destroy**](docs/ExpenseCategoriesApi.md#expense_category_destroy) | **DELETE** /expense_categories/{id}.json | Delete a single ExpenseCategory
*ExpenseCategoriesApi* | [**expense_category_index**](docs/ExpenseCategoriesApi.md#expense_category_index) | **GET** /expense_categories.json | Return the data for all ExpenseCategories
*ExpenseCategoriesApi* | [**expense_category_show**](docs/ExpenseCategoriesApi.md#expense_category_show) | **GET** /expense_categories/{id}.json | Return the data for a single ExpenseCategory
*ExpenseCategoriesApi* | [**expense_category_update**](docs/ExpenseCategoriesApi.md#expense_category_update) | **PATCH** /expense_categories/{id}.json | Update a single ExpenseCategory
*ExpenseCategoriesApi* | [**lauk_expense_category_index**](docs/ExpenseCategoriesApi.md#lauk_expense_category_index) | **GET** /lauk_expense_categories.json | List Expense Categories
*FoldersApi* | [**folder_create**](docs/FoldersApi.md#folder_create) | **POST** /folders.json | Create a new Folder
*FoldersApi* | [**folder_destroy**](docs/FoldersApi.md#folder_destroy) | **DELETE** /folders/{id}.json | Delete a single Folder
*FoldersApi* | [**folder_index**](docs/FoldersApi.md#folder_index) | **GET** /folders.json | Return the data for all Folders
*FoldersApi* | [**folder_list**](docs/FoldersApi.md#folder_list) | **GET** /folders/list.json | Return the data of the contents of a Folder
*FoldersApi* | [**folder_show**](docs/FoldersApi.md#folder_show) | **GET** /folders/{id}.json | Return the data for a single Folder
*FoldersApi* | [**folder_update**](docs/FoldersApi.md#folder_update) | **PATCH** /folders/{id}.json | Update a single Folder
*GrantFundingSourcesApi* | [**grant_funding_source_create**](docs/GrantFundingSourcesApi.md#grant_funding_source_create) | **POST** /grant_funding_sources.json | Create a new grant funding source
*GrantFundingSourcesApi* | [**grant_funding_source_destroy**](docs/GrantFundingSourcesApi.md#grant_funding_source_destroy) | **DELETE** /grant_funding_sources/{id}.json | Delete a single grant funding source
*GrantFundingSourcesApi* | [**grant_funding_source_index**](docs/GrantFundingSourcesApi.md#grant_funding_source_index) | **GET** /grant_funding_sources.json | Return the data for all grant funding sources
*GrantFundingSourcesApi* | [**grant_funding_source_update**](docs/GrantFundingSourcesApi.md#grant_funding_source_update) | **PATCH** /grant_funding_sources/{id}.json | Update a single grant funding source
*GrantsApi* | [**grant_create**](docs/GrantsApi.md#grant_create) | **POST** /grants.json | Create a new grant
*GrantsApi* | [**grant_destroy**](docs/GrantsApi.md#grant_destroy) | **DELETE** /grants/{id}.json | Deletes a single grant
*GrantsApi* | [**grant_index**](docs/GrantsApi.md#grant_index) | **GET** /grants.json | Return the data for all grants
*GrantsApi* | [**grant_show**](docs/GrantsApi.md#grant_show) | **GET** /grants/{id}.json | Return the data for a single grant
*GrantsApi* | [**grant_update**](docs/GrantsApi.md#grant_update) | **PATCH** /grants/{id}.json | Update a single grant
*GroupsApi* | [**group_create**](docs/GroupsApi.md#group_create) | **POST** /groups.json | Create a new Group
*GroupsApi* | [**group_destroy**](docs/GroupsApi.md#group_destroy) | **DELETE** /groups/{id}.json | Delete a single Group
*GroupsApi* | [**group_index**](docs/GroupsApi.md#group_index) | **GET** /groups.json | Return the data for all Groups
*GroupsApi* | [**group_show**](docs/GroupsApi.md#group_show) | **GET** /groups/{id}.json | Return the data for a single Group
*GroupsApi* | [**group_update**](docs/GroupsApi.md#group_update) | **PATCH** /groups/{id}.json | Update a single Group
*InterestChargesApi* | [**interest_charge_destroy**](docs/InterestChargesApi.md#interest_charge_destroy) | **DELETE** /interest_charges/{id}.json | Delete a single InterestCharge
*InterestChargesApi* | [**interest_charge_index**](docs/InterestChargesApi.md#interest_charge_index) | **GET** /interest_charges.json | Return the data for all InterestCharges
*JurisdictionsApi* | [**jurisdiction_index**](docs/JurisdictionsApi.md#jurisdiction_index) | **GET** /court_rules/jurisdictions.json | Return the data for all jurisdictions
*JurisdictionsApi* | [**jurisdiction_show**](docs/JurisdictionsApi.md#jurisdiction_show) | **GET** /court_rules/jurisdictions/{id}.json | Return the data for the jurisdiction
*JurisdictionsToTriggersApi* | [**jurisdictions_to_trigger_index**](docs/JurisdictionsToTriggersApi.md#jurisdictions_to_trigger_index) | **GET** /court_rules/jurisdictions/{jurisdiction_id}/triggers.json | Return the data for all triggers
*JurisdictionsToTriggersApi* | [**jurisdictions_to_trigger_show**](docs/JurisdictionsToTriggersApi.md#jurisdictions_to_trigger_show) | **GET** /court_rules/jurisdictions/{jurisdiction_id}/triggers/{id}.json | Return the data for the trigger
*LineItemsApi* | [**line_item_destroy**](docs/LineItemsApi.md#line_item_destroy) | **DELETE** /line_items/{id}.json | Delete a single LineItem
*LineItemsApi* | [**line_item_index**](docs/LineItemsApi.md#line_item_index) | **GET** /line_items.json | Return the data for all LineItems
*LineItemsApi* | [**line_item_update**](docs/LineItemsApi.md#line_item_update) | **PATCH** /line_items/{id}.json | Update a single LineItem
*LogEntriesApi* | [**log_entry_index**](docs/LogEntriesApi.md#log_entry_index) | **GET** /log_entries.json | Return the data for all LogEntries
*MatterContactsApi* | [**matter_contacts_index**](docs/MatterContactsApi.md#matter_contacts_index) | **GET** /matters/{matter_id}/contacts.json | Return the related contact data for a single matter
*MatterDocketsApi* | [**matter_docket_create**](docs/MatterDocketsApi.md#matter_docket_create) | **POST** /court_rules/matter_dockets.json | Creates a matter docket
*MatterDocketsApi* | [**matter_docket_destroy**](docs/MatterDocketsApi.md#matter_docket_destroy) | **DELETE** /court_rules/matter_dockets/{id}.json | Deletes the requested matter docket
*MatterDocketsApi* | [**matter_docket_index**](docs/MatterDocketsApi.md#matter_docket_index) | **GET** /court_rules/matter_dockets.json | Return the data for all matter dockets
*MatterDocketsApi* | [**matter_docket_preview**](docs/MatterDocketsApi.md#matter_docket_preview) | **GET** /court_rules/matter_dockets/preview.json | Preview calendar dates for the docket
*MatterDocketsApi* | [**matter_docket_show**](docs/MatterDocketsApi.md#matter_docket_show) | **GET** /court_rules/matter_dockets/{id}.json | Return the data for the matter docket
*MatterStagesApi* | [**matter_stage_index**](docs/MatterStagesApi.md#matter_stage_index) | **GET** /matter_stages.json | Return the data for all MatterStages
*MattersApi* | [**matter_create**](docs/MattersApi.md#matter_create) | **POST** /matters.json | Create a new Matter
*MattersApi* | [**matter_destroy**](docs/MattersApi.md#matter_destroy) | **DELETE** /matters/{id}.json | Delete a single Matter
*MattersApi* | [**matter_index**](docs/MattersApi.md#matter_index) | **GET** /matters.json | Return the data for all Matters
*MattersApi* | [**matter_show**](docs/MattersApi.md#matter_show) | **GET** /matters/{id}.json | Return the data for a single Matter
*MattersApi* | [**matter_update**](docs/MattersApi.md#matter_update) | **PATCH** /matters/{id}.json | Update a single Matter
*MedicalBillsApi* | [**medical_bill_destroy**](docs/MedicalBillsApi.md#medical_bill_destroy) | **DELETE** /medical_bills/{id}.json | Destroying a Medical Bill
*MedicalBillsApi* | [**medical_bill_update**](docs/MedicalBillsApi.md#medical_bill_update) | **PATCH** /medical_bills/{id}.json | Updating a Medical Bill
*MedicalRecordsApi* | [**medical_record_destroy**](docs/MedicalRecordsApi.md#medical_record_destroy) | **DELETE** /medical_records/{id}.json | Destroying a Medical Record
*MedicalRecordsApi* | [**medical_record_update**](docs/MedicalRecordsApi.md#medical_record_update) | **PATCH** /medical_records/{id}.json | Updating a Medical Record
*MedicalRecordsDetailsApi* | [**medical_records_request_create**](docs/MedicalRecordsDetailsApi.md#medical_records_request_create) | **POST** /medical_records_details.json | Creating a Medical Records Detail, Medical Records and Medical Bills
*MedicalRecordsDetailsApi* | [**medical_records_request_destroy**](docs/MedicalRecordsDetailsApi.md#medical_records_request_destroy) | **DELETE** /medical_records_details/{id}.json | Destroying a Medical Records Detail
*MedicalRecordsDetailsApi* | [**medical_records_request_index**](docs/MedicalRecordsDetailsApi.md#medical_records_request_index) | **GET** /medical_records_details.json | Return the data for all Medical Records Details
*MedicalRecordsDetailsApi* | [**medical_records_request_show**](docs/MedicalRecordsDetailsApi.md#medical_records_request_show) | **GET** /medical_records_details/{id}.json | Return the data for a single Medical Records Detail
*MedicalRecordsDetailsApi* | [**medical_records_request_update**](docs/MedicalRecordsDetailsApi.md#medical_records_request_update) | **PATCH** /medical_records_details/{id}.json | Updating a Medical Records Detail
*MyEventsApi* | [**my_event_destroy**](docs/MyEventsApi.md#my_event_destroy) | **DELETE** /internal_notifications/my_events/{id}.json | Clear (delete) a single in-app notification event
*MyEventsApi* | [**my_event_index**](docs/MyEventsApi.md#my_event_index) | **GET** /internal_notifications/my_events.json | Return the data for all of my in-app notification events
*MyEventsApi* | [**my_event_update**](docs/MyEventsApi.md#my_event_update) | **PATCH** /internal_notifications/my_events/{id}.json | Mark a single in-app notification event as read/unread
*NotesApi* | [**note_create**](docs/NotesApi.md#note_create) | **POST** /notes.json | Create a new Note
*NotesApi* | [**note_destroy**](docs/NotesApi.md#note_destroy) | **DELETE** /notes/{id}.json | Delete a single Note
*NotesApi* | [**note_index**](docs/NotesApi.md#note_index) | **GET** /notes.json | Return the data for all Notes
*NotesApi* | [**note_show**](docs/NotesApi.md#note_show) | **GET** /notes/{id}.json | Return the data for a single Note
*NotesApi* | [**note_update**](docs/NotesApi.md#note_update) | **PATCH** /notes/{id}.json | Update a single Note
*OutstandingClientBalancesApi* | [**outstanding_client_balance_index**](docs/OutstandingClientBalancesApi.md#outstanding_client_balance_index) | **GET** /outstanding_client_balances.json | Return the data for all OutstandingClientBalances
*PracticeAreasApi* | [**practice_area_create**](docs/PracticeAreasApi.md#practice_area_create) | **POST** /practice_areas.json | Create a new PracticeArea
*PracticeAreasApi* | [**practice_area_destroy**](docs/PracticeAreasApi.md#practice_area_destroy) | **DELETE** /practice_areas/{id}.json | Delete a single PracticeArea
*PracticeAreasApi* | [**practice_area_index**](docs/PracticeAreasApi.md#practice_area_index) | **GET** /practice_areas.json | Return the data for all PracticeAreas
*PracticeAreasApi* | [**practice_area_show**](docs/PracticeAreasApi.md#practice_area_show) | **GET** /practice_areas/{id}.json | Return the data for a single PracticeArea
*PracticeAreasApi* | [**practice_area_update**](docs/PracticeAreasApi.md#practice_area_update) | **PATCH** /practice_areas/{id}.json | Update a single PracticeArea
*RelatedContactsApi* | [**related_contacts_index**](docs/RelatedContactsApi.md#related_contacts_index) | **GET** /matters/{matter_id}/related_contacts.json | Return the related contact data for a single matter
*RelationshipsApi* | [**relationship_create**](docs/RelationshipsApi.md#relationship_create) | **POST** /relationships.json | Create a new Relationship
*RelationshipsApi* | [**relationship_destroy**](docs/RelationshipsApi.md#relationship_destroy) | **DELETE** /relationships/{id}.json | Delete a single Relationship
*RelationshipsApi* | [**relationship_index**](docs/RelationshipsApi.md#relationship_index) | **GET** /relationships.json | Return the data for all Relationships
*RelationshipsApi* | [**relationship_show**](docs/RelationshipsApi.md#relationship_show) | **GET** /relationships/{id}.json | Return the data for a single Relationship
*RelationshipsApi* | [**relationship_update**](docs/RelationshipsApi.md#relationship_update) | **PATCH** /relationships/{id}.json | Update a single Relationship
*RemindersApi* | [**reminder_create**](docs/RemindersApi.md#reminder_create) | **POST** /reminders.json | Create a new Reminder
*RemindersApi* | [**reminder_destroy**](docs/RemindersApi.md#reminder_destroy) | **DELETE** /reminders/{id}.json | Delete a single Reminder
*RemindersApi* | [**reminder_index**](docs/RemindersApi.md#reminder_index) | **GET** /reminders.json | Return the data for all Reminders
*RemindersApi* | [**reminder_show**](docs/RemindersApi.md#reminder_show) | **GET** /reminders/{id}.json | Return the data for a single Reminder
*RemindersApi* | [**reminder_update**](docs/RemindersApi.md#reminder_update) | **PATCH** /reminders/{id}.json | Update a single Reminder
*ReportPresetsApi* | [**report_preset_create**](docs/ReportPresetsApi.md#report_preset_create) | **POST** /report_presets.json | Create a new ReportPreset
*ReportPresetsApi* | [**report_preset_destroy**](docs/ReportPresetsApi.md#report_preset_destroy) | **DELETE** /report_presets/{id}.json | Delete a single ReportPreset
*ReportPresetsApi* | [**report_preset_generate_report**](docs/ReportPresetsApi.md#report_preset_generate_report) | **POST** /report_presets/{id}/generate_report.json | Generate a new report for a given preset
*ReportPresetsApi* | [**report_preset_index**](docs/ReportPresetsApi.md#report_preset_index) | **GET** /report_presets.json | Return the data for all ReportPresets
*ReportPresetsApi* | [**report_preset_show**](docs/ReportPresetsApi.md#report_preset_show) | **GET** /report_presets/{id}.json | Return the data for a single ReportPreset
*ReportPresetsApi* | [**report_preset_update**](docs/ReportPresetsApi.md#report_preset_update) | **PATCH** /report_presets/{id}.json | Update a single ReportPreset
*ReportSchedulesApi* | [**report_schedule_create**](docs/ReportSchedulesApi.md#report_schedule_create) | **POST** /report_schedules.json | Create a new ReportSchedule
*ReportSchedulesApi* | [**report_schedule_destroy**](docs/ReportSchedulesApi.md#report_schedule_destroy) | **DELETE** /report_schedules/{id}.json | Delete a single ReportSchedule
*ReportSchedulesApi* | [**report_schedule_index**](docs/ReportSchedulesApi.md#report_schedule_index) | **GET** /report_schedules.json | Return the data for all ReportSchedules
*ReportSchedulesApi* | [**report_schedule_show**](docs/ReportSchedulesApi.md#report_schedule_show) | **GET** /report_schedules/{id}.json | Return the data for a single ReportSchedule
*ReportSchedulesApi* | [**report_schedule_update**](docs/ReportSchedulesApi.md#report_schedule_update) | **PATCH** /report_schedules/{id}.json | Update a single ReportSchedule
*ReportsApi* | [**report_create**](docs/ReportsApi.md#report_create) | **POST** /reports.json | Create a new Report
*ReportsApi* | [**report_download**](docs/ReportsApi.md#report_download) | **GET** /reports/{id}/download.json | Download the completed Report
*ReportsApi* | [**report_index**](docs/ReportsApi.md#report_index) | **GET** /reports.json | Return the data for all Reports
*ReportsApi* | [**report_show**](docs/ReportsApi.md#report_show) | **GET** /reports/{id}.json | Return the data for a single Report
*ServiceTypesApi* | [**service_type_index**](docs/ServiceTypesApi.md#service_type_index) | **GET** /court_rules/service_types.json | Return the data for all service types
*ServiceTypesApi* | [**service_type_show**](docs/ServiceTypesApi.md#service_type_show) | **GET** /court_rules/service_types/{id}.json | Return the data for the service type
*TaskTemplateListsApi* | [**task_template_list_copy**](docs/TaskTemplateListsApi.md#task_template_list_copy) | **POST** /task_template_lists/{id}/copy.json | Copy a TaskTemplateList
*TaskTemplateListsApi* | [**task_template_list_create**](docs/TaskTemplateListsApi.md#task_template_list_create) | **POST** /task_template_lists.json | Create a new TaskTemplateList
*TaskTemplateListsApi* | [**task_template_list_destroy**](docs/TaskTemplateListsApi.md#task_template_list_destroy) | **DELETE** /task_template_lists/{id}.json | Delete a single TaskTemplateList
*TaskTemplateListsApi* | [**task_template_list_index**](docs/TaskTemplateListsApi.md#task_template_list_index) | **GET** /task_template_lists.json | Return the data for all TaskTemplateLists
*TaskTemplateListsApi* | [**task_template_list_show**](docs/TaskTemplateListsApi.md#task_template_list_show) | **GET** /task_template_lists/{id}.json | Return the data for a single TaskTemplateList
*TaskTemplateListsApi* | [**task_template_list_update**](docs/TaskTemplateListsApi.md#task_template_list_update) | **PATCH** /task_template_lists/{id}.json | Update a single TaskTemplateList
*TaskTemplatesApi* | [**task_template_create**](docs/TaskTemplatesApi.md#task_template_create) | **POST** /task_templates.json | Create a new TaskTemplate
*TaskTemplatesApi* | [**task_template_destroy**](docs/TaskTemplatesApi.md#task_template_destroy) | **DELETE** /task_templates/{id}.json | Delete a single TaskTemplate
*TaskTemplatesApi* | [**task_template_index**](docs/TaskTemplatesApi.md#task_template_index) | **GET** /task_templates.json | Return the data for all TaskTemplates
*TaskTemplatesApi* | [**task_template_show**](docs/TaskTemplatesApi.md#task_template_show) | **GET** /task_templates/{id}.json | Return the data for a single TaskTemplate
*TaskTemplatesApi* | [**task_template_update**](docs/TaskTemplatesApi.md#task_template_update) | **PATCH** /task_templates/{id}.json | Update a single TaskTemplate
*TaskTypesApi* | [**task_type_create**](docs/TaskTypesApi.md#task_type_create) | **POST** /task_types.json | Create a new TaskType
*TaskTypesApi* | [**task_type_index**](docs/TaskTypesApi.md#task_type_index) | **GET** /task_types.json | Return the data for all TaskTypes
*TaskTypesApi* | [**task_type_show**](docs/TaskTypesApi.md#task_type_show) | **GET** /task_types/{id}.json | Return the data for a single TaskType
*TaskTypesApi* | [**task_type_update**](docs/TaskTypesApi.md#task_type_update) | **PATCH** /task_types/{id}.json | Update a single TaskType
*TasksApi* | [**task_create**](docs/TasksApi.md#task_create) | **POST** /tasks.json | Create a new Task
*TasksApi* | [**task_destroy**](docs/TasksApi.md#task_destroy) | **DELETE** /tasks/{id}.json | Delete a single Task
*TasksApi* | [**task_index**](docs/TasksApi.md#task_index) | **GET** /tasks.json | Return the data for all Tasks
*TasksApi* | [**task_show**](docs/TasksApi.md#task_show) | **GET** /tasks/{id}.json | Return the data for a single Task
*TasksApi* | [**task_update**](docs/TasksApi.md#task_update) | **PATCH** /tasks/{id}.json | Update a single Task
*TextSnippetsApi* | [**text_snippet_create**](docs/TextSnippetsApi.md#text_snippet_create) | **POST** /settings/text_snippets.json | Create a text snippet
*TextSnippetsApi* | [**text_snippet_destroy**](docs/TextSnippetsApi.md#text_snippet_destroy) | **DELETE** /settings/text_snippets/{id}.json | Destroy a text snippet
*TextSnippetsApi* | [**text_snippet_index**](docs/TextSnippetsApi.md#text_snippet_index) | **GET** /settings/text_snippets.json | Return all text snippets
*TextSnippetsApi* | [**text_snippet_show**](docs/TextSnippetsApi.md#text_snippet_show) | **GET** /settings/text_snippets/{id}.json | Return the data for the text snippet
*TextSnippetsApi* | [**text_snippet_update**](docs/TextSnippetsApi.md#text_snippet_update) | **PATCH** /settings/text_snippets/{id}.json | Update a text snippet
*TimersApi* | [**timer_create**](docs/TimersApi.md#timer_create) | **POST** /timer.json | Create a new Timer
*TimersApi* | [**timer_destroy**](docs/TimersApi.md#timer_destroy) | **DELETE** /timer.json | Delete a single Timer
*TimersApi* | [**timer_show**](docs/TimersApi.md#timer_show) | **GET** /timer.json | Return the data for a single Timer
*TrustLineItemsApi* | [**trust_line_item_index**](docs/TrustLineItemsApi.md#trust_line_item_index) | **GET** /trust_line_items.json | Return the data for all TrustLineItems
*TrustLineItemsApi* | [**trust_line_item_update**](docs/TrustLineItemsApi.md#trust_line_item_update) | **PATCH** /trust_line_items/{id}.json | Update a single TrustLineItem
*TrustRequestsApi* | [**trust_request_create**](docs/TrustRequestsApi.md#trust_request_create) | **POST** /trust_requests.json | Create a new TrustRequest
*UsersApi* | [**user_index**](docs/UsersApi.md#user_index) | **GET** /users.json | Return the data for all Users
*UsersApi* | [**user_show**](docs/UsersApi.md#user_show) | **GET** /users/{id}.json | Return the data for a single User
*UsersApi* | [**user_who_am_i**](docs/UsersApi.md#user_who_am_i) | **GET** /users/who_am_i.json | Return the data for the current User
*UtbmsCodesApi* | [**utbms_code_index**](docs/UtbmsCodesApi.md#utbms_code_index) | **GET** /utbms/codes.json | Return the data for all UtbmsCodes
*UtbmsCodesApi* | [**utbms_code_show**](docs/UtbmsCodesApi.md#utbms_code_show) | **GET** /utbms/codes/{id}.json | Return the data for a single UtbmsCode
*UtbmsSetsApi* | [**utbms_set_index**](docs/UtbmsSetsApi.md#utbms_set_index) | **GET** /utbms/sets.json | Return the data for all the utbms sets
*WebhooksApi* | [**webhook_create**](docs/WebhooksApi.md#webhook_create) | **POST** /webhooks.json | Create a new Webhook
*WebhooksApi* | [**webhook_destroy**](docs/WebhooksApi.md#webhook_destroy) | **DELETE** /webhooks/{id}.json | Delete a single Webhook
*WebhooksApi* | [**webhook_index**](docs/WebhooksApi.md#webhook_index) | **GET** /webhooks.json | Return the data for all Webhooks
*WebhooksApi* | [**webhook_show**](docs/WebhooksApi.md#webhook_show) | **GET** /webhooks/{id}.json | Return the data for a single Webhook
*WebhooksApi* | [**webhook_update**](docs/WebhooksApi.md#webhook_update) | **PATCH** /webhooks/{id}.json | Update a single Webhook


## Documentation For Models

 - [Account](docs/Account.md)
 - [AccountBalanceBase](docs/AccountBalanceBase.md)
 - [AccountBase](docs/AccountBase.md)
 - [Activity](docs/Activity.md)
 - [ActivityBase](docs/ActivityBase.md)
 - [ActivityCalendarEntryBase](docs/ActivityCalendarEntryBase.md)
 - [ActivityCreateRequest](docs/ActivityCreateRequest.md)
 - [ActivityCreateRequestData](docs/ActivityCreateRequestData.md)
 - [ActivityCreateRequestDataActivityDescription](docs/ActivityCreateRequestDataActivityDescription.md)
 - [ActivityCreateRequestDataCalendarEntry](docs/ActivityCreateRequestDataCalendarEntry.md)
 - [ActivityCreateRequestDataClientPortal](docs/ActivityCreateRequestDataClientPortal.md)
 - [ActivityCreateRequestDataCommunication](docs/ActivityCreateRequestDataCommunication.md)
 - [ActivityCreateRequestDataContactNote](docs/ActivityCreateRequestDataContactNote.md)
 - [ActivityCreateRequestDataExpenseCategory](docs/ActivityCreateRequestDataExpenseCategory.md)
 - [ActivityCreateRequestDataMatter](docs/ActivityCreateRequestDataMatter.md)
 - [ActivityCreateRequestDataTask](docs/ActivityCreateRequestDataTask.md)
 - [ActivityCreateRequestDataTextMessageConversation](docs/ActivityCreateRequestDataTextMessageConversation.md)
 - [ActivityCreateRequestDataUser](docs/ActivityCreateRequestDataUser.md)
 - [ActivityCreateRequestDataUtbmsExpense](docs/ActivityCreateRequestDataUtbmsExpense.md)
 - [ActivityCreateRequestDataVendor](docs/ActivityCreateRequestDataVendor.md)
 - [ActivityDescription](docs/ActivityDescription.md)
 - [ActivityDescriptionBase](docs/ActivityDescriptionBase.md)
 - [ActivityDescriptionCreateRequest](docs/ActivityDescriptionCreateRequest.md)
 - [ActivityDescriptionCreateRequestData](docs/ActivityDescriptionCreateRequestData.md)
 - [ActivityDescriptionCreateRequestDataGroupsInner](docs/ActivityDescriptionCreateRequestDataGroupsInner.md)
 - [ActivityDescriptionCreateRequestDataRate](docs/ActivityDescriptionCreateRequestDataRate.md)
 - [ActivityDescriptionList](docs/ActivityDescriptionList.md)
 - [ActivityDescriptionRateBase](docs/ActivityDescriptionRateBase.md)
 - [ActivityDescriptionShow](docs/ActivityDescriptionShow.md)
 - [ActivityDescriptionUpdateRequest](docs/ActivityDescriptionUpdateRequest.md)
 - [ActivityDescriptionUpdateRequestData](docs/ActivityDescriptionUpdateRequestData.md)
 - [ActivityDescriptionUpdateRequestDataGroupsInner](docs/ActivityDescriptionUpdateRequestDataGroupsInner.md)
 - [ActivityList](docs/ActivityList.md)
 - [ActivityRate](docs/ActivityRate.md)
 - [ActivityRateBase](docs/ActivityRateBase.md)
 - [ActivityRateCreateRequest](docs/ActivityRateCreateRequest.md)
 - [ActivityRateCreateRequestData](docs/ActivityRateCreateRequestData.md)
 - [ActivityRateList](docs/ActivityRateList.md)
 - [ActivityRateShow](docs/ActivityRateShow.md)
 - [ActivityShow](docs/ActivityShow.md)
 - [ActivityTaskBase](docs/ActivityTaskBase.md)
 - [ActivityTextMessageConversationBase](docs/ActivityTextMessageConversationBase.md)
 - [ActivityUpdateRequest](docs/ActivityUpdateRequest.md)
 - [ActivityUpdateRequestData](docs/ActivityUpdateRequestData.md)
 - [AddressBase](docs/AddressBase.md)
 - [Allocation](docs/Allocation.md)
 - [AllocationBase](docs/AllocationBase.md)
 - [AllocationList](docs/AllocationList.md)
 - [AllocationShow](docs/AllocationShow.md)
 - [AttendeeBase](docs/AttendeeBase.md)
 - [AvatarBase](docs/AvatarBase.md)
 - [Balance](docs/Balance.md)
 - [BalanceBase](docs/BalanceBase.md)
 - [BankAccount](docs/BankAccount.md)
 - [BankAccountBase](docs/BankAccountBase.md)
 - [BankAccountCreateRequest](docs/BankAccountCreateRequest.md)
 - [BankAccountCreateRequestData](docs/BankAccountCreateRequestData.md)
 - [BankAccountList](docs/BankAccountList.md)
 - [BankAccountShow](docs/BankAccountShow.md)
 - [BankAccountUpdateRequest](docs/BankAccountUpdateRequest.md)
 - [BankAccountUpdateRequestData](docs/BankAccountUpdateRequestData.md)
 - [BankTransaction](docs/BankTransaction.md)
 - [BankTransactionBase](docs/BankTransactionBase.md)
 - [BankTransactionList](docs/BankTransactionList.md)
 - [BankTransactionShow](docs/BankTransactionShow.md)
 - [BankTransfer](docs/BankTransfer.md)
 - [BankTransferBase](docs/BankTransferBase.md)
 - [BankTransferShow](docs/BankTransferShow.md)
 - [Bill](docs/Bill.md)
 - [BillBase](docs/BillBase.md)
 - [BillList](docs/BillList.md)
 - [BillRecipient](docs/BillRecipient.md)
 - [BillRecipientBase](docs/BillRecipientBase.md)
 - [BillRecipientContactBase](docs/BillRecipientContactBase.md)
 - [BillShow](docs/BillShow.md)
 - [BillTheme](docs/BillTheme.md)
 - [BillThemeBase](docs/BillThemeBase.md)
 - [BillThemeList](docs/BillThemeList.md)
 - [BillThemeShow](docs/BillThemeShow.md)
 - [BillThemeUpdateRequest](docs/BillThemeUpdateRequest.md)
 - [BillThemeUpdateRequestData](docs/BillThemeUpdateRequestData.md)
 - [BillUpdateRequest](docs/BillUpdateRequest.md)
 - [BillUpdateRequestData](docs/BillUpdateRequestData.md)
 - [BillUpdateRequestDataBillTheme](docs/BillUpdateRequestDataBillTheme.md)
 - [BillUpdateRequestDataDiscount](docs/BillUpdateRequestDataDiscount.md)
 - [BillUpdateRequestDataInterest](docs/BillUpdateRequestDataInterest.md)
 - [BillableClient](docs/BillableClient.md)
 - [BillableClientBase](docs/BillableClientBase.md)
 - [BillableClientList](docs/BillableClientList.md)
 - [BillableMatter](docs/BillableMatter.md)
 - [BillableMatterBase](docs/BillableMatterBase.md)
 - [BillableMatterList](docs/BillableMatterList.md)
 - [BillableMatterShow](docs/BillableMatterShow.md)
 - [BillingSetting](docs/BillingSetting.md)
 - [BillingSettingBase](docs/BillingSettingBase.md)
 - [BillingSettingShow](docs/BillingSettingShow.md)
 - [Calendar](docs/Calendar.md)
 - [CalendarBase](docs/CalendarBase.md)
 - [CalendarCreateRequest](docs/CalendarCreateRequest.md)
 - [CalendarCreateRequestData](docs/CalendarCreateRequestData.md)
 - [CalendarEntry](docs/CalendarEntry.md)
 - [CalendarEntryBase](docs/CalendarEntryBase.md)
 - [CalendarEntryCreateRequest](docs/CalendarEntryCreateRequest.md)
 - [CalendarEntryCreateRequestData](docs/CalendarEntryCreateRequestData.md)
 - [CalendarEntryCreateRequestDataAttendeesInner](docs/CalendarEntryCreateRequestDataAttendeesInner.md)
 - [CalendarEntryCreateRequestDataCalendarEntryEventType](docs/CalendarEntryCreateRequestDataCalendarEntryEventType.md)
 - [CalendarEntryCreateRequestDataCalendarOwner](docs/CalendarEntryCreateRequestDataCalendarOwner.md)
 - [CalendarEntryCreateRequestDataConferenceMeeting](docs/CalendarEntryCreateRequestDataConferenceMeeting.md)
 - [CalendarEntryCreateRequestDataExternalPropertiesInner](docs/CalendarEntryCreateRequestDataExternalPropertiesInner.md)
 - [CalendarEntryCreateRequestDataMatter](docs/CalendarEntryCreateRequestDataMatter.md)
 - [CalendarEntryEventType](docs/CalendarEntryEventType.md)
 - [CalendarEntryEventTypeBase](docs/CalendarEntryEventTypeBase.md)
 - [CalendarEntryEventTypeCreateRequest](docs/CalendarEntryEventTypeCreateRequest.md)
 - [CalendarEntryEventTypeCreateRequestData](docs/CalendarEntryEventTypeCreateRequestData.md)
 - [CalendarEntryEventTypeUpdateRequest](docs/CalendarEntryEventTypeUpdateRequest.md)
 - [CalendarEntryEventTypeUpdateRequestData](docs/CalendarEntryEventTypeUpdateRequestData.md)
 - [CalendarEntryList](docs/CalendarEntryList.md)
 - [CalendarEntryShow](docs/CalendarEntryShow.md)
 - [CalendarEntryUpdateRequest](docs/CalendarEntryUpdateRequest.md)
 - [CalendarEntryUpdateRequestData](docs/CalendarEntryUpdateRequestData.md)
 - [CalendarEntryUpdateRequestDataCalendarOwner](docs/CalendarEntryUpdateRequestDataCalendarOwner.md)
 - [CalendarEntryUpdateRequestDataExternalPropertiesInner](docs/CalendarEntryUpdateRequestDataExternalPropertiesInner.md)
 - [CalendarList](docs/CalendarList.md)
 - [CalendarShow](docs/CalendarShow.md)
 - [CalendarUpdateRequest](docs/CalendarUpdateRequest.md)
 - [CalendarUpdateRequestData](docs/CalendarUpdateRequestData.md)
 - [CalendarVisibility](docs/CalendarVisibility.md)
 - [CalendarVisibilityBase](docs/CalendarVisibilityBase.md)
 - [CalendarVisibilityList](docs/CalendarVisibilityList.md)
 - [CalendarVisibilityShow](docs/CalendarVisibilityShow.md)
 - [CalendarVisibilityUpdateRequest](docs/CalendarVisibilityUpdateRequest.md)
 - [CalendarVisibilityUpdateRequestData](docs/CalendarVisibilityUpdateRequestData.md)
 - [CascadingTaskTemplateBase](docs/CascadingTaskTemplateBase.md)
 - [Client](docs/Client.md)
 - [ClientBase](docs/ClientBase.md)
 - [ClientPortalBase](docs/ClientPortalBase.md)
 - [ClientShow](docs/ClientShow.md)
 - [ClioCreatorBase](docs/ClioCreatorBase.md)
 - [ClioPaymentsLink](docs/ClioPaymentsLink.md)
 - [ClioPaymentsLinkBase](docs/ClioPaymentsLinkBase.md)
 - [ClioPaymentsLinkCreateRequest](docs/ClioPaymentsLinkCreateRequest.md)
 - [ClioPaymentsLinkCreateRequestData](docs/ClioPaymentsLinkCreateRequestData.md)
 - [ClioPaymentsLinkCreateRequestDataDestinationAccount](docs/ClioPaymentsLinkCreateRequestDataDestinationAccount.md)
 - [ClioPaymentsLinkCreateRequestDataDestinationContact](docs/ClioPaymentsLinkCreateRequestDataDestinationContact.md)
 - [ClioPaymentsLinkCreateRequestDataSubject](docs/ClioPaymentsLinkCreateRequestDataSubject.md)
 - [ClioPaymentsLinkList](docs/ClioPaymentsLinkList.md)
 - [ClioPaymentsLinkShow](docs/ClioPaymentsLinkShow.md)
 - [ClioPaymentsLinkUpdateRequest](docs/ClioPaymentsLinkUpdateRequest.md)
 - [ClioPaymentsLinkUpdateRequestData](docs/ClioPaymentsLinkUpdateRequestData.md)
 - [ClioPaymentsPayment](docs/ClioPaymentsPayment.md)
 - [ClioPaymentsPaymentBase](docs/ClioPaymentsPaymentBase.md)
 - [ClioPaymentsPaymentList](docs/ClioPaymentsPaymentList.md)
 - [ClioPaymentsPaymentShow](docs/ClioPaymentsPaymentShow.md)
 - [Comment](docs/Comment.md)
 - [CommentBase](docs/CommentBase.md)
 - [CommentCreateRequest](docs/CommentCreateRequest.md)
 - [CommentCreateRequestData](docs/CommentCreateRequestData.md)
 - [CommentCreateRequestDataItem](docs/CommentCreateRequestDataItem.md)
 - [CommentList](docs/CommentList.md)
 - [CommentShow](docs/CommentShow.md)
 - [CommentUpdateRequest](docs/CommentUpdateRequest.md)
 - [CommentUpdateRequestData](docs/CommentUpdateRequestData.md)
 - [CommentUpdateRequestDataItem](docs/CommentUpdateRequestDataItem.md)
 - [Communication](docs/Communication.md)
 - [CommunicationBase](docs/CommunicationBase.md)
 - [CommunicationCreateRequest](docs/CommunicationCreateRequest.md)
 - [CommunicationCreateRequestData](docs/CommunicationCreateRequestData.md)
 - [CommunicationCreateRequestDataExternalPropertiesInner](docs/CommunicationCreateRequestDataExternalPropertiesInner.md)
 - [CommunicationCreateRequestDataMatter](docs/CommunicationCreateRequestDataMatter.md)
 - [CommunicationCreateRequestDataNotificationEventSubscribersInner](docs/CommunicationCreateRequestDataNotificationEventSubscribersInner.md)
 - [CommunicationCreateRequestDataReceiversInner](docs/CommunicationCreateRequestDataReceiversInner.md)
 - [CommunicationCreateRequestDataSendersInner](docs/CommunicationCreateRequestDataSendersInner.md)
 - [CommunicationEmlFileBase](docs/CommunicationEmlFileBase.md)
 - [CommunicationList](docs/CommunicationList.md)
 - [CommunicationShow](docs/CommunicationShow.md)
 - [CommunicationUpdateRequest](docs/CommunicationUpdateRequest.md)
 - [CommunicationUpdateRequestData](docs/CommunicationUpdateRequestData.md)
 - [CommunicationUpdateRequestDataExternalPropertiesInner](docs/CommunicationUpdateRequestDataExternalPropertiesInner.md)
 - [CommunicationUpdateRequestDataNotificationEventSubscribersInner](docs/CommunicationUpdateRequestDataNotificationEventSubscribersInner.md)
 - [ConferenceMeetingBase](docs/ConferenceMeetingBase.md)
 - [Contact](docs/Contact.md)
 - [ContactBase](docs/ContactBase.md)
 - [ContactCreateRequest](docs/ContactCreateRequest.md)
 - [ContactCreateRequestData](docs/ContactCreateRequestData.md)
 - [ContactCreateRequestDataAddressesInner](docs/ContactCreateRequestDataAddressesInner.md)
 - [ContactCreateRequestDataAvatar](docs/ContactCreateRequestDataAvatar.md)
 - [ContactCreateRequestDataCoCounselRate](docs/ContactCreateRequestDataCoCounselRate.md)
 - [ContactCreateRequestDataCompany](docs/ContactCreateRequestDataCompany.md)
 - [ContactCreateRequestDataCustomFieldSetAssociationsInner](docs/ContactCreateRequestDataCustomFieldSetAssociationsInner.md)
 - [ContactCreateRequestDataCustomFieldSetAssociationsInnerCustomFieldSet](docs/ContactCreateRequestDataCustomFieldSetAssociationsInnerCustomFieldSet.md)
 - [ContactCreateRequestDataCustomFieldValuesInner](docs/ContactCreateRequestDataCustomFieldValuesInner.md)
 - [ContactCreateRequestDataCustomFieldValuesInnerCustomField](docs/ContactCreateRequestDataCustomFieldValuesInnerCustomField.md)
 - [ContactCreateRequestDataEmailAddressesInner](docs/ContactCreateRequestDataEmailAddressesInner.md)
 - [ContactCreateRequestDataInstantMessengersInner](docs/ContactCreateRequestDataInstantMessengersInner.md)
 - [ContactCreateRequestDataPhoneNumbersInner](docs/ContactCreateRequestDataPhoneNumbersInner.md)
 - [ContactCreateRequestDataWebSitesInner](docs/ContactCreateRequestDataWebSitesInner.md)
 - [ContactList](docs/ContactList.md)
 - [ContactShow](docs/ContactShow.md)
 - [ContactUpdateRequest](docs/ContactUpdateRequest.md)
 - [ContactUpdateRequestData](docs/ContactUpdateRequestData.md)
 - [ContactUpdateRequestDataAddressesInner](docs/ContactUpdateRequestDataAddressesInner.md)
 - [ContactUpdateRequestDataCustomFieldSetAssociationsInner](docs/ContactUpdateRequestDataCustomFieldSetAssociationsInner.md)
 - [ContactUpdateRequestDataCustomFieldSetAssociationsInnerCustomFieldSet](docs/ContactUpdateRequestDataCustomFieldSetAssociationsInnerCustomFieldSet.md)
 - [ContactUpdateRequestDataCustomFieldValuesInner](docs/ContactUpdateRequestDataCustomFieldValuesInner.md)
 - [ContactUpdateRequestDataCustomFieldValuesInnerCustomField](docs/ContactUpdateRequestDataCustomFieldValuesInnerCustomField.md)
 - [ContactUpdateRequestDataEmailAddressesInner](docs/ContactUpdateRequestDataEmailAddressesInner.md)
 - [ContactUpdateRequestDataInstantMessengersInner](docs/ContactUpdateRequestDataInstantMessengersInner.md)
 - [ContactUpdateRequestDataPhoneNumbersInner](docs/ContactUpdateRequestDataPhoneNumbersInner.md)
 - [ContactUpdateRequestDataWebSitesInner](docs/ContactUpdateRequestDataWebSitesInner.md)
 - [ContingencyFeeBase](docs/ContingencyFeeBase.md)
 - [Conversation](docs/Conversation.md)
 - [ConversationBase](docs/ConversationBase.md)
 - [ConversationList](docs/ConversationList.md)
 - [ConversationMembership](docs/ConversationMembership.md)
 - [ConversationMembershipBase](docs/ConversationMembershipBase.md)
 - [ConversationMessage](docs/ConversationMessage.md)
 - [ConversationMessageBase](docs/ConversationMessageBase.md)
 - [ConversationMessageCreateRequest](docs/ConversationMessageCreateRequest.md)
 - [ConversationMessageCreateRequestData](docs/ConversationMessageCreateRequestData.md)
 - [ConversationMessageCreateRequestDataAttachment](docs/ConversationMessageCreateRequestDataAttachment.md)
 - [ConversationMessageCreateRequestDataConversation](docs/ConversationMessageCreateRequestDataConversation.md)
 - [ConversationMessageCreateRequestDataMatter](docs/ConversationMessageCreateRequestDataMatter.md)
 - [ConversationMessageCreateRequestDataReceiversInner](docs/ConversationMessageCreateRequestDataReceiversInner.md)
 - [ConversationMessageList](docs/ConversationMessageList.md)
 - [ConversationMessageShow](docs/ConversationMessageShow.md)
 - [ConversationShow](docs/ConversationShow.md)
 - [ConversationUpdateRequest](docs/ConversationUpdateRequest.md)
 - [ConversationUpdateRequestData](docs/ConversationUpdateRequestData.md)
 - [ConversationUpdateRequestDataMatter](docs/ConversationUpdateRequestDataMatter.md)
 - [CreditMemo](docs/CreditMemo.md)
 - [CreditMemoBase](docs/CreditMemoBase.md)
 - [CreditMemoList](docs/CreditMemoList.md)
 - [CreditMemoShow](docs/CreditMemoShow.md)
 - [Currency](docs/Currency.md)
 - [CurrencyBase](docs/CurrencyBase.md)
 - [CurrencyList](docs/CurrencyList.md)
 - [CustomAction](docs/CustomAction.md)
 - [CustomActionBase](docs/CustomActionBase.md)
 - [CustomActionCreateRequest](docs/CustomActionCreateRequest.md)
 - [CustomActionCreateRequestData](docs/CustomActionCreateRequestData.md)
 - [CustomActionList](docs/CustomActionList.md)
 - [CustomActionShow](docs/CustomActionShow.md)
 - [CustomActionUpdateRequest](docs/CustomActionUpdateRequest.md)
 - [CustomActionUpdateRequestData](docs/CustomActionUpdateRequestData.md)
 - [CustomField](docs/CustomField.md)
 - [CustomFieldBase](docs/CustomFieldBase.md)
 - [CustomFieldCreateRequest](docs/CustomFieldCreateRequest.md)
 - [CustomFieldCreateRequestData](docs/CustomFieldCreateRequestData.md)
 - [CustomFieldCreateRequestDataPicklistOptionsInner](docs/CustomFieldCreateRequestDataPicklistOptionsInner.md)
 - [CustomFieldList](docs/CustomFieldList.md)
 - [CustomFieldMatterSelection](docs/CustomFieldMatterSelection.md)
 - [CustomFieldMatterSelectionBase](docs/CustomFieldMatterSelectionBase.md)
 - [CustomFieldSet](docs/CustomFieldSet.md)
 - [CustomFieldSetAssociationBase](docs/CustomFieldSetAssociationBase.md)
 - [CustomFieldSetBase](docs/CustomFieldSetBase.md)
 - [CustomFieldSetCreateRequest](docs/CustomFieldSetCreateRequest.md)
 - [CustomFieldSetCreateRequestData](docs/CustomFieldSetCreateRequestData.md)
 - [CustomFieldSetList](docs/CustomFieldSetList.md)
 - [CustomFieldSetShow](docs/CustomFieldSetShow.md)
 - [CustomFieldSetUpdateRequest](docs/CustomFieldSetUpdateRequest.md)
 - [CustomFieldSetUpdateRequestData](docs/CustomFieldSetUpdateRequestData.md)
 - [CustomFieldShow](docs/CustomFieldShow.md)
 - [CustomFieldUpdateRequest](docs/CustomFieldUpdateRequest.md)
 - [CustomFieldUpdateRequestData](docs/CustomFieldUpdateRequestData.md)
 - [CustomFieldValue](docs/CustomFieldValue.md)
 - [CustomFieldValueBase](docs/CustomFieldValueBase.md)
 - [Damage](docs/Damage.md)
 - [DamageBase](docs/DamageBase.md)
 - [DamageCreateRequest](docs/DamageCreateRequest.md)
 - [DamageCreateRequestData](docs/DamageCreateRequestData.md)
 - [DamageList](docs/DamageList.md)
 - [DamageShow](docs/DamageShow.md)
 - [DamageUpdateRequest](docs/DamageUpdateRequest.md)
 - [DamageUpdateRequestData](docs/DamageUpdateRequestData.md)
 - [DiscountBase](docs/DiscountBase.md)
 - [Document](docs/Document.md)
 - [DocumentArchive](docs/DocumentArchive.md)
 - [DocumentArchiveBase](docs/DocumentArchiveBase.md)
 - [DocumentArchiveCreateRequest](docs/DocumentArchiveCreateRequest.md)
 - [DocumentArchiveCreateRequestData](docs/DocumentArchiveCreateRequestData.md)
 - [DocumentArchiveCreateRequestDataItemsInner](docs/DocumentArchiveCreateRequestDataItemsInner.md)
 - [DocumentArchiveShow](docs/DocumentArchiveShow.md)
 - [DocumentAutomation](docs/DocumentAutomation.md)
 - [DocumentAutomationBase](docs/DocumentAutomationBase.md)
 - [DocumentAutomationCreateRequest](docs/DocumentAutomationCreateRequest.md)
 - [DocumentAutomationCreateRequestData](docs/DocumentAutomationCreateRequestData.md)
 - [DocumentAutomationCreateRequestDataDocumentTemplate](docs/DocumentAutomationCreateRequestDataDocumentTemplate.md)
 - [DocumentAutomationCreateRequestDataMatter](docs/DocumentAutomationCreateRequestDataMatter.md)
 - [DocumentAutomationList](docs/DocumentAutomationList.md)
 - [DocumentAutomationShow](docs/DocumentAutomationShow.md)
 - [DocumentBase](docs/DocumentBase.md)
 - [DocumentCategory](docs/DocumentCategory.md)
 - [DocumentCategoryBase](docs/DocumentCategoryBase.md)
 - [DocumentCategoryCreateRequest](docs/DocumentCategoryCreateRequest.md)
 - [DocumentCategoryCreateRequestData](docs/DocumentCategoryCreateRequestData.md)
 - [DocumentCategoryList](docs/DocumentCategoryList.md)
 - [DocumentCategoryShow](docs/DocumentCategoryShow.md)
 - [DocumentCategoryUpdateRequest](docs/DocumentCategoryUpdateRequest.md)
 - [DocumentCategoryUpdateRequestData](docs/DocumentCategoryUpdateRequestData.md)
 - [DocumentCopyRequest](docs/DocumentCopyRequest.md)
 - [DocumentCopyRequestData](docs/DocumentCopyRequestData.md)
 - [DocumentCopyRequestDataDocumentCategory](docs/DocumentCopyRequestDataDocumentCategory.md)
 - [DocumentCopyRequestDataExternalPropertiesInner](docs/DocumentCopyRequestDataExternalPropertiesInner.md)
 - [DocumentCopyRequestDataParent](docs/DocumentCopyRequestDataParent.md)
 - [DocumentCreateRequest](docs/DocumentCreateRequest.md)
 - [DocumentCreateRequestData](docs/DocumentCreateRequestData.md)
 - [DocumentCreateRequestDataExternalPropertiesInner](docs/DocumentCreateRequestDataExternalPropertiesInner.md)
 - [DocumentCreateRequestDataMultipartsInner](docs/DocumentCreateRequestDataMultipartsInner.md)
 - [DocumentList](docs/DocumentList.md)
 - [DocumentShow](docs/DocumentShow.md)
 - [DocumentTemplate](docs/DocumentTemplate.md)
 - [DocumentTemplateBase](docs/DocumentTemplateBase.md)
 - [DocumentTemplateCreateRequest](docs/DocumentTemplateCreateRequest.md)
 - [DocumentTemplateCreateRequestData](docs/DocumentTemplateCreateRequestData.md)
 - [DocumentTemplateCreateRequestDataDocumentCategory](docs/DocumentTemplateCreateRequestDataDocumentCategory.md)
 - [DocumentTemplateList](docs/DocumentTemplateList.md)
 - [DocumentTemplateShow](docs/DocumentTemplateShow.md)
 - [DocumentTemplateUpdateRequest](docs/DocumentTemplateUpdateRequest.md)
 - [DocumentTemplateUpdateRequestData](docs/DocumentTemplateUpdateRequestData.md)
 - [DocumentUpdateRequest](docs/DocumentUpdateRequest.md)
 - [DocumentUpdateRequestData](docs/DocumentUpdateRequestData.md)
 - [DocumentUpdateRequestDataMultipartsInner](docs/DocumentUpdateRequestDataMultipartsInner.md)
 - [DocumentUpdateRequestDataParent](docs/DocumentUpdateRequestDataParent.md)
 - [DocumentVersion](docs/DocumentVersion.md)
 - [DocumentVersionBase](docs/DocumentVersionBase.md)
 - [DocumentVersionList](docs/DocumentVersionList.md)
 - [EmailAddressBase](docs/EmailAddressBase.md)
 - [Error](docs/Error.md)
 - [ErrorDetail](docs/ErrorDetail.md)
 - [Event](docs/Event.md)
 - [EventBase](docs/EventBase.md)
 - [EventMetrics](docs/EventMetrics.md)
 - [EventMetricsBase](docs/EventMetricsBase.md)
 - [EventMetricsShow](docs/EventMetricsShow.md)
 - [EvergreenRetainerBase](docs/EvergreenRetainerBase.md)
 - [ExpenseCategory](docs/ExpenseCategory.md)
 - [ExpenseCategoryBase](docs/ExpenseCategoryBase.md)
 - [ExpenseCategoryCreateRequest](docs/ExpenseCategoryCreateRequest.md)
 - [ExpenseCategoryCreateRequestData](docs/ExpenseCategoryCreateRequestData.md)
 - [ExpenseCategoryCreateRequestDataGroupsInner](docs/ExpenseCategoryCreateRequestDataGroupsInner.md)
 - [ExpenseCategoryCreateRequestDataUtbmsCode](docs/ExpenseCategoryCreateRequestDataUtbmsCode.md)
 - [ExpenseCategoryList](docs/ExpenseCategoryList.md)
 - [ExpenseCategoryShow](docs/ExpenseCategoryShow.md)
 - [ExpenseCategoryUpdateRequest](docs/ExpenseCategoryUpdateRequest.md)
 - [ExpenseCategoryUpdateRequestData](docs/ExpenseCategoryUpdateRequestData.md)
 - [ExternalPropertyBase](docs/ExternalPropertyBase.md)
 - [Folder](docs/Folder.md)
 - [FolderBase](docs/FolderBase.md)
 - [FolderCreateRequest](docs/FolderCreateRequest.md)
 - [FolderCreateRequestData](docs/FolderCreateRequestData.md)
 - [FolderCreateRequestDataDocumentCategory](docs/FolderCreateRequestDataDocumentCategory.md)
 - [FolderCreateRequestDataExternalPropertiesInner](docs/FolderCreateRequestDataExternalPropertiesInner.md)
 - [FolderCreateRequestDataParent](docs/FolderCreateRequestDataParent.md)
 - [FolderList](docs/FolderList.md)
 - [FolderShow](docs/FolderShow.md)
 - [FolderUpdateRequest](docs/FolderUpdateRequest.md)
 - [FolderUpdateRequestData](docs/FolderUpdateRequestData.md)
 - [FolderUpdateRequestDataExternalPropertiesInner](docs/FolderUpdateRequestDataExternalPropertiesInner.md)
 - [FolderUpdateRequestDataParent](docs/FolderUpdateRequestDataParent.md)
 - [Grant](docs/Grant.md)
 - [GrantBase](docs/GrantBase.md)
 - [GrantCreateRequest](docs/GrantCreateRequest.md)
 - [GrantCreateRequestData](docs/GrantCreateRequestData.md)
 - [GrantFundingSource](docs/GrantFundingSource.md)
 - [GrantFundingSourceBase](docs/GrantFundingSourceBase.md)
 - [GrantFundingSourceCreateRequest](docs/GrantFundingSourceCreateRequest.md)
 - [GrantFundingSourceCreateRequestData](docs/GrantFundingSourceCreateRequestData.md)
 - [GrantFundingSourceList](docs/GrantFundingSourceList.md)
 - [GrantFundingSourceShow](docs/GrantFundingSourceShow.md)
 - [GrantList](docs/GrantList.md)
 - [GrantShow](docs/GrantShow.md)
 - [Group](docs/Group.md)
 - [GroupBase](docs/GroupBase.md)
 - [GroupCreateRequest](docs/GroupCreateRequest.md)
 - [GroupCreateRequestData](docs/GroupCreateRequestData.md)
 - [GroupList](docs/GroupList.md)
 - [GroupShow](docs/GroupShow.md)
 - [IdsResponse](docs/IdsResponse.md)
 - [InstantMessengerBase](docs/InstantMessengerBase.md)
 - [Interest](docs/Interest.md)
 - [InterestBase](docs/InterestBase.md)
 - [InterestCharge](docs/InterestCharge.md)
 - [InterestChargeBase](docs/InterestChargeBase.md)
 - [InterestChargeList](docs/InterestChargeList.md)
 - [Item](docs/Item.md)
 - [ItemBase](docs/ItemBase.md)
 - [ItemList](docs/ItemList.md)
 - [JobTitleBase](docs/JobTitleBase.md)
 - [Jurisdiction](docs/Jurisdiction.md)
 - [JurisdictionBase](docs/JurisdictionBase.md)
 - [JurisdictionList](docs/JurisdictionList.md)
 - [JurisdictionShow](docs/JurisdictionShow.md)
 - [JurisdictionsToTrigger](docs/JurisdictionsToTrigger.md)
 - [JurisdictionsToTriggerBase](docs/JurisdictionsToTriggerBase.md)
 - [JurisdictionsToTriggerList](docs/JurisdictionsToTriggerList.md)
 - [JurisdictionsToTriggerShow](docs/JurisdictionsToTriggerShow.md)
 - [LaukCivilCertificatedRate](docs/LaukCivilCertificatedRate.md)
 - [LaukCivilCertificatedRateBase](docs/LaukCivilCertificatedRateBase.md)
 - [LaukCivilCertificatedRateList](docs/LaukCivilCertificatedRateList.md)
 - [LaukCivilControlledRate](docs/LaukCivilControlledRate.md)
 - [LaukCivilControlledRateBase](docs/LaukCivilControlledRateBase.md)
 - [LaukCivilControlledRateList](docs/LaukCivilControlledRateList.md)
 - [LaukCriminalControlledRate](docs/LaukCriminalControlledRate.md)
 - [LaukCriminalControlledRateBase](docs/LaukCriminalControlledRateBase.md)
 - [LaukCriminalControlledRateList](docs/LaukCriminalControlledRateList.md)
 - [LaukExpenseCategory](docs/LaukExpenseCategory.md)
 - [LaukExpenseCategoryBase](docs/LaukExpenseCategoryBase.md)
 - [LaukExpenseCategoryList](docs/LaukExpenseCategoryList.md)
 - [LegalAidUkActivityBase](docs/LegalAidUkActivityBase.md)
 - [LegalAidUkBillBase](docs/LegalAidUkBillBase.md)
 - [LegalAidUkContactBase](docs/LegalAidUkContactBase.md)
 - [LegalAidUkMatterBase](docs/LegalAidUkMatterBase.md)
 - [LienBase](docs/LienBase.md)
 - [LineItem](docs/LineItem.md)
 - [LineItemBase](docs/LineItemBase.md)
 - [LineItemList](docs/LineItemList.md)
 - [LineItemShow](docs/LineItemShow.md)
 - [LineItemTotalsBase](docs/LineItemTotalsBase.md)
 - [LineItemUpdateRequest](docs/LineItemUpdateRequest.md)
 - [LineItemUpdateRequestData](docs/LineItemUpdateRequestData.md)
 - [LineItemUpdateRequestDataActivity](docs/LineItemUpdateRequestDataActivity.md)
 - [LineItemUpdateRequestDataBill](docs/LineItemUpdateRequestDataBill.md)
 - [LineItemUpdateRequestDataDiscount](docs/LineItemUpdateRequestDataDiscount.md)
 - [LineItemUpdateRequestDataMatter](docs/LineItemUpdateRequestDataMatter.md)
 - [LinkedFolderBase](docs/LinkedFolderBase.md)
 - [LogEntry](docs/LogEntry.md)
 - [LogEntryBase](docs/LogEntryBase.md)
 - [LogEntryList](docs/LogEntryList.md)
 - [Matter](docs/Matter.md)
 - [MatterBalanceBase](docs/MatterBalanceBase.md)
 - [MatterBase](docs/MatterBase.md)
 - [MatterBillRecipient](docs/MatterBillRecipient.md)
 - [MatterBillRecipientBase](docs/MatterBillRecipientBase.md)
 - [MatterBudgetBase](docs/MatterBudgetBase.md)
 - [MatterContacts](docs/MatterContacts.md)
 - [MatterContactsBase](docs/MatterContactsBase.md)
 - [MatterContactsList](docs/MatterContactsList.md)
 - [MatterCreateRequest](docs/MatterCreateRequest.md)
 - [MatterCreateRequestData](docs/MatterCreateRequestData.md)
 - [MatterCreateRequestDataClient](docs/MatterCreateRequestDataClient.md)
 - [MatterCreateRequestDataCustomFieldSetAssociationsInner](docs/MatterCreateRequestDataCustomFieldSetAssociationsInner.md)
 - [MatterCreateRequestDataCustomRate](docs/MatterCreateRequestDataCustomRate.md)
 - [MatterCreateRequestDataCustomRateRatesInner](docs/MatterCreateRequestDataCustomRateRatesInner.md)
 - [MatterCreateRequestDataCustomRateRatesInnerActivityDescription](docs/MatterCreateRequestDataCustomRateRatesInnerActivityDescription.md)
 - [MatterCreateRequestDataCustomRateRatesInnerGroup](docs/MatterCreateRequestDataCustomRateRatesInnerGroup.md)
 - [MatterCreateRequestDataCustomRateRatesInnerUser](docs/MatterCreateRequestDataCustomRateRatesInnerUser.md)
 - [MatterCreateRequestDataEvergreenRetainer](docs/MatterCreateRequestDataEvergreenRetainer.md)
 - [MatterCreateRequestDataEvergreenRetainerRecipientsInner](docs/MatterCreateRequestDataEvergreenRetainerRecipientsInner.md)
 - [MatterCreateRequestDataGroup](docs/MatterCreateRequestDataGroup.md)
 - [MatterCreateRequestDataMatterBudget](docs/MatterCreateRequestDataMatterBudget.md)
 - [MatterCreateRequestDataMatterStage](docs/MatterCreateRequestDataMatterStage.md)
 - [MatterCreateRequestDataOriginatingAttorney](docs/MatterCreateRequestDataOriginatingAttorney.md)
 - [MatterCreateRequestDataPracticeArea](docs/MatterCreateRequestDataPracticeArea.md)
 - [MatterCreateRequestDataRelationshipsInner](docs/MatterCreateRequestDataRelationshipsInner.md)
 - [MatterCreateRequestDataRelationshipsInnerContact](docs/MatterCreateRequestDataRelationshipsInnerContact.md)
 - [MatterCreateRequestDataSplitInvoicePayersInner](docs/MatterCreateRequestDataSplitInvoicePayersInner.md)
 - [MatterCreateRequestDataStatuteOfLimitations](docs/MatterCreateRequestDataStatuteOfLimitations.md)
 - [MatterCreateRequestDataStatuteOfLimitationsRemindersInner](docs/MatterCreateRequestDataStatuteOfLimitationsRemindersInner.md)
 - [MatterCreateRequestDataStatuteOfLimitationsRemindersInnerNotificationMethod](docs/MatterCreateRequestDataStatuteOfLimitationsRemindersInnerNotificationMethod.md)
 - [MatterCreateRequestDataTaskTemplateListInstancesInner](docs/MatterCreateRequestDataTaskTemplateListInstancesInner.md)
 - [MatterCreateRequestDataTaskTemplateListInstancesInnerTaskTemplateList](docs/MatterCreateRequestDataTaskTemplateListInstancesInnerTaskTemplateList.md)
 - [MatterCustomRate](docs/MatterCustomRate.md)
 - [MatterCustomRateBase](docs/MatterCustomRateBase.md)
 - [MatterDocket](docs/MatterDocket.md)
 - [MatterDocketBase](docs/MatterDocketBase.md)
 - [MatterDocketCreateRequest](docs/MatterDocketCreateRequest.md)
 - [MatterDocketCreateRequestData](docs/MatterDocketCreateRequestData.md)
 - [MatterDocketCreateRequestDataJurisdiction](docs/MatterDocketCreateRequestDataJurisdiction.md)
 - [MatterDocketCreateRequestDataTrigger](docs/MatterDocketCreateRequestDataTrigger.md)
 - [MatterDocketList](docs/MatterDocketList.md)
 - [MatterDocketShow](docs/MatterDocketShow.md)
 - [MatterList](docs/MatterList.md)
 - [MatterShow](docs/MatterShow.md)
 - [MatterStage](docs/MatterStage.md)
 - [MatterStageBase](docs/MatterStageBase.md)
 - [MatterStageList](docs/MatterStageList.md)
 - [MatterUpdateRequest](docs/MatterUpdateRequest.md)
 - [MatterUpdateRequestData](docs/MatterUpdateRequestData.md)
 - [MatterUpdateRequestDataClient](docs/MatterUpdateRequestDataClient.md)
 - [MatterUpdateRequestDataCustomFieldSetAssociationsInner](docs/MatterUpdateRequestDataCustomFieldSetAssociationsInner.md)
 - [MatterUpdateRequestDataCustomFieldValuesInner](docs/MatterUpdateRequestDataCustomFieldValuesInner.md)
 - [MatterUpdateRequestDataCustomRate](docs/MatterUpdateRequestDataCustomRate.md)
 - [MatterUpdateRequestDataCustomRateRatesInner](docs/MatterUpdateRequestDataCustomRateRatesInner.md)
 - [MatterUpdateRequestDataCustomRateRatesInnerUser](docs/MatterUpdateRequestDataCustomRateRatesInnerUser.md)
 - [MatterUpdateRequestDataEvergreenRetainer](docs/MatterUpdateRequestDataEvergreenRetainer.md)
 - [MatterUpdateRequestDataRelationshipsInner](docs/MatterUpdateRequestDataRelationshipsInner.md)
 - [MatterUpdateRequestDataRelationshipsInnerContact](docs/MatterUpdateRequestDataRelationshipsInnerContact.md)
 - [MatterUpdateRequestDataSplitInvoicePayersInner](docs/MatterUpdateRequestDataSplitInvoicePayersInner.md)
 - [MatterUpdateRequestDataStatuteOfLimitations](docs/MatterUpdateRequestDataStatuteOfLimitations.md)
 - [MatterUpdateRequestDataStatuteOfLimitationsRemindersInner](docs/MatterUpdateRequestDataStatuteOfLimitationsRemindersInner.md)
 - [MatterUpdateRequestDataStatuteOfLimitationsRemindersInnerNotificationMethod](docs/MatterUpdateRequestDataStatuteOfLimitationsRemindersInnerNotificationMethod.md)
 - [MatterUpdateRequestDataTaskTemplateListInstancesInner](docs/MatterUpdateRequestDataTaskTemplateListInstancesInner.md)
 - [MatterUpdateRequestDataTaskTemplateListInstancesInnerTaskTemplateList](docs/MatterUpdateRequestDataTaskTemplateListInstancesInnerTaskTemplateList.md)
 - [MedicalBill](docs/MedicalBill.md)
 - [MedicalBillBase](docs/MedicalBillBase.md)
 - [MedicalBillShow](docs/MedicalBillShow.md)
 - [MedicalBillUpdateRequest](docs/MedicalBillUpdateRequest.md)
 - [MedicalBillUpdateRequestData](docs/MedicalBillUpdateRequestData.md)
 - [MedicalBillUpdateRequestDataPayersInner](docs/MedicalBillUpdateRequestDataPayersInner.md)
 - [MedicalRecord](docs/MedicalRecord.md)
 - [MedicalRecordBase](docs/MedicalRecordBase.md)
 - [MedicalRecordShow](docs/MedicalRecordShow.md)
 - [MedicalRecordUpdateRequest](docs/MedicalRecordUpdateRequest.md)
 - [MedicalRecordUpdateRequestData](docs/MedicalRecordUpdateRequestData.md)
 - [MedicalRecordsRequest](docs/MedicalRecordsRequest.md)
 - [MedicalRecordsRequestBase](docs/MedicalRecordsRequestBase.md)
 - [MedicalRecordsRequestCreateRequest](docs/MedicalRecordsRequestCreateRequest.md)
 - [MedicalRecordsRequestCreateRequestData](docs/MedicalRecordsRequestCreateRequestData.md)
 - [MedicalRecordsRequestCreateRequestDataMedicalBillsInner](docs/MedicalRecordsRequestCreateRequestDataMedicalBillsInner.md)
 - [MedicalRecordsRequestCreateRequestDataMedicalBillsInnerPayersInner](docs/MedicalRecordsRequestCreateRequestDataMedicalBillsInnerPayersInner.md)
 - [MedicalRecordsRequestCreateRequestDataMedicalRecordsInner](docs/MedicalRecordsRequestCreateRequestDataMedicalRecordsInner.md)
 - [MedicalRecordsRequestList](docs/MedicalRecordsRequestList.md)
 - [MedicalRecordsRequestShow](docs/MedicalRecordsRequestShow.md)
 - [MedicalRecordsRequestUpdateRequest](docs/MedicalRecordsRequestUpdateRequest.md)
 - [MedicalRecordsRequestUpdateRequestData](docs/MedicalRecordsRequestUpdateRequestData.md)
 - [MedicalRecordsRequestUpdateRequestDataMedicalBillsInner](docs/MedicalRecordsRequestUpdateRequestDataMedicalBillsInner.md)
 - [MedicalRecordsRequestUpdateRequestDataMedicalBillsInnerPayersInner](docs/MedicalRecordsRequestUpdateRequestDataMedicalBillsInnerPayersInner.md)
 - [MedicalRecordsRequestUpdateRequestDataMedicalRecordsInner](docs/MedicalRecordsRequestUpdateRequestDataMedicalRecordsInner.md)
 - [Multipart](docs/Multipart.md)
 - [MultipartBase](docs/MultipartBase.md)
 - [MultipartHeaderBase](docs/MultipartHeaderBase.md)
 - [MyEvent](docs/MyEvent.md)
 - [MyEventList](docs/MyEventList.md)
 - [MyEventShow](docs/MyEventShow.md)
 - [MyEventUpdateRequest](docs/MyEventUpdateRequest.md)
 - [MyEventUpdateRequestData](docs/MyEventUpdateRequestData.md)
 - [Note](docs/Note.md)
 - [NoteBase](docs/NoteBase.md)
 - [NoteCreateRequest](docs/NoteCreateRequest.md)
 - [NoteCreateRequestData](docs/NoteCreateRequestData.md)
 - [NoteCreateRequestDataContact](docs/NoteCreateRequestDataContact.md)
 - [NoteCreateRequestDataMatter](docs/NoteCreateRequestDataMatter.md)
 - [NoteCreateRequestDataNotificationEventSubscribersInner](docs/NoteCreateRequestDataNotificationEventSubscribersInner.md)
 - [NoteList](docs/NoteList.md)
 - [NoteShow](docs/NoteShow.md)
 - [NoteUpdateRequest](docs/NoteUpdateRequest.md)
 - [NoteUpdateRequestData](docs/NoteUpdateRequestData.md)
 - [NoteUpdateRequestDataNotificationEventSubscribersInner](docs/NoteUpdateRequestDataNotificationEventSubscribersInner.md)
 - [NotificationEventSubscriberBase](docs/NotificationEventSubscriberBase.md)
 - [NotificationMethodBase](docs/NotificationMethodBase.md)
 - [OutstandingClientBalance](docs/OutstandingClientBalance.md)
 - [OutstandingClientBalanceBase](docs/OutstandingClientBalanceBase.md)
 - [OutstandingClientBalanceList](docs/OutstandingClientBalanceList.md)
 - [Participant](docs/Participant.md)
 - [ParticipantBase](docs/ParticipantBase.md)
 - [Payment](docs/Payment.md)
 - [PaymentBase](docs/PaymentBase.md)
 - [PaymentProfileBase](docs/PaymentProfileBase.md)
 - [PhoneNumberBase](docs/PhoneNumberBase.md)
 - [PicklistOption](docs/PicklistOption.md)
 - [PicklistOptionBase](docs/PicklistOptionBase.md)
 - [PolymorphicCustomRate](docs/PolymorphicCustomRate.md)
 - [PolymorphicCustomRateActivityDescriptionBase](docs/PolymorphicCustomRateActivityDescriptionBase.md)
 - [PolymorphicCustomRateBase](docs/PolymorphicCustomRateBase.md)
 - [PolymorphicCustomRateGroupBase](docs/PolymorphicCustomRateGroupBase.md)
 - [PolymorphicCustomRateUserBase](docs/PolymorphicCustomRateUserBase.md)
 - [PolymorphicObjectBase](docs/PolymorphicObjectBase.md)
 - [PracticeArea](docs/PracticeArea.md)
 - [PracticeAreaBase](docs/PracticeAreaBase.md)
 - [PracticeAreaCreateRequest](docs/PracticeAreaCreateRequest.md)
 - [PracticeAreaCreateRequestData](docs/PracticeAreaCreateRequestData.md)
 - [PracticeAreaList](docs/PracticeAreaList.md)
 - [PracticeAreaShow](docs/PracticeAreaShow.md)
 - [PracticeAreaUpdateRequest](docs/PracticeAreaUpdateRequest.md)
 - [PracticeAreaUpdateRequestData](docs/PracticeAreaUpdateRequestData.md)
 - [RelatedContacts](docs/RelatedContacts.md)
 - [RelatedContactsBase](docs/RelatedContactsBase.md)
 - [RelatedContactsList](docs/RelatedContactsList.md)
 - [Relationship](docs/Relationship.md)
 - [RelationshipBase](docs/RelationshipBase.md)
 - [RelationshipCreateRequest](docs/RelationshipCreateRequest.md)
 - [RelationshipCreateRequestData](docs/RelationshipCreateRequestData.md)
 - [RelationshipCreateRequestDataMatter](docs/RelationshipCreateRequestDataMatter.md)
 - [RelationshipList](docs/RelationshipList.md)
 - [RelationshipShow](docs/RelationshipShow.md)
 - [Reminder](docs/Reminder.md)
 - [ReminderBase](docs/ReminderBase.md)
 - [ReminderCreateRequest](docs/ReminderCreateRequest.md)
 - [ReminderCreateRequestData](docs/ReminderCreateRequestData.md)
 - [ReminderCreateRequestDataSubject](docs/ReminderCreateRequestDataSubject.md)
 - [ReminderList](docs/ReminderList.md)
 - [ReminderShow](docs/ReminderShow.md)
 - [ReminderTemplateBase](docs/ReminderTemplateBase.md)
 - [ReminderUpdateRequest](docs/ReminderUpdateRequest.md)
 - [ReminderUpdateRequestData](docs/ReminderUpdateRequestData.md)
 - [Report](docs/Report.md)
 - [ReportBase](docs/ReportBase.md)
 - [ReportCreateRequest](docs/ReportCreateRequest.md)
 - [ReportCreateRequestData](docs/ReportCreateRequestData.md)
 - [ReportCreateRequestDataClient](docs/ReportCreateRequestDataClient.md)
 - [ReportCreateRequestDataMatter](docs/ReportCreateRequestDataMatter.md)
 - [ReportCreateRequestDataOriginatingAttorney](docs/ReportCreateRequestDataOriginatingAttorney.md)
 - [ReportCreateRequestDataPracticeArea](docs/ReportCreateRequestDataPracticeArea.md)
 - [ReportList](docs/ReportList.md)
 - [ReportPreset](docs/ReportPreset.md)
 - [ReportPresetBase](docs/ReportPresetBase.md)
 - [ReportPresetCreateRequest](docs/ReportPresetCreateRequest.md)
 - [ReportPresetCreateRequestData](docs/ReportPresetCreateRequestData.md)
 - [ReportPresetList](docs/ReportPresetList.md)
 - [ReportPresetShow](docs/ReportPresetShow.md)
 - [ReportPresetUpdateRequest](docs/ReportPresetUpdateRequest.md)
 - [ReportPresetUpdateRequestData](docs/ReportPresetUpdateRequestData.md)
 - [ReportSchedule](docs/ReportSchedule.md)
 - [ReportScheduleBase](docs/ReportScheduleBase.md)
 - [ReportScheduleCreateRequest](docs/ReportScheduleCreateRequest.md)
 - [ReportScheduleCreateRequestData](docs/ReportScheduleCreateRequestData.md)
 - [ReportScheduleList](docs/ReportScheduleList.md)
 - [ReportScheduleShow](docs/ReportScheduleShow.md)
 - [ReportScheduleUpdateRequest](docs/ReportScheduleUpdateRequest.md)
 - [ReportScheduleUpdateRequestData](docs/ReportScheduleUpdateRequestData.md)
 - [ReportShow](docs/ReportShow.md)
 - [ServiceType](docs/ServiceType.md)
 - [ServiceTypeBase](docs/ServiceTypeBase.md)
 - [ServiceTypeList](docs/ServiceTypeList.md)
 - [ServiceTypeShow](docs/ServiceTypeShow.md)
 - [Task](docs/Task.md)
 - [TaskBase](docs/TaskBase.md)
 - [TaskCreateRequest](docs/TaskCreateRequest.md)
 - [TaskCreateRequestData](docs/TaskCreateRequestData.md)
 - [TaskCreateRequestDataAssignee](docs/TaskCreateRequestDataAssignee.md)
 - [TaskCreateRequestDataMatter](docs/TaskCreateRequestDataMatter.md)
 - [TaskCreateRequestDataTaskType](docs/TaskCreateRequestDataTaskType.md)
 - [TaskList](docs/TaskList.md)
 - [TaskShow](docs/TaskShow.md)
 - [TaskTemplate](docs/TaskTemplate.md)
 - [TaskTemplateBase](docs/TaskTemplateBase.md)
 - [TaskTemplateCreateRequest](docs/TaskTemplateCreateRequest.md)
 - [TaskTemplateCreateRequestData](docs/TaskTemplateCreateRequestData.md)
 - [TaskTemplateCreateRequestDataCascadingSource](docs/TaskTemplateCreateRequestDataCascadingSource.md)
 - [TaskTemplateCreateRequestDataReminderTemplatesInner](docs/TaskTemplateCreateRequestDataReminderTemplatesInner.md)
 - [TaskTemplateCreateRequestDataTaskTemplateList](docs/TaskTemplateCreateRequestDataTaskTemplateList.md)
 - [TaskTemplateList](docs/TaskTemplateList.md)
 - [TaskTemplateListBase](docs/TaskTemplateListBase.md)
 - [TaskTemplateListCopyRequest](docs/TaskTemplateListCopyRequest.md)
 - [TaskTemplateListCopyRequestData](docs/TaskTemplateListCopyRequestData.md)
 - [TaskTemplateListCopyRequestDataPracticeArea](docs/TaskTemplateListCopyRequestDataPracticeArea.md)
 - [TaskTemplateListCreateRequest](docs/TaskTemplateListCreateRequest.md)
 - [TaskTemplateListCreateRequestData](docs/TaskTemplateListCreateRequestData.md)
 - [TaskTemplateListCreateRequestDataPracticeArea](docs/TaskTemplateListCreateRequestDataPracticeArea.md)
 - [TaskTemplateListInstaceBase](docs/TaskTemplateListInstaceBase.md)
 - [TaskTemplateListList](docs/TaskTemplateListList.md)
 - [TaskTemplateListShow](docs/TaskTemplateListShow.md)
 - [TaskTemplateListUpdateRequest](docs/TaskTemplateListUpdateRequest.md)
 - [TaskTemplateListUpdateRequestData](docs/TaskTemplateListUpdateRequestData.md)
 - [TaskTemplateShow](docs/TaskTemplateShow.md)
 - [TaskTemplateUpdateRequest](docs/TaskTemplateUpdateRequest.md)
 - [TaskTemplateUpdateRequestData](docs/TaskTemplateUpdateRequestData.md)
 - [TaskTemplateUpdateRequestDataReminderTemplatesInner](docs/TaskTemplateUpdateRequestDataReminderTemplatesInner.md)
 - [TaskType](docs/TaskType.md)
 - [TaskTypeBase](docs/TaskTypeBase.md)
 - [TaskTypeCreateRequest](docs/TaskTypeCreateRequest.md)
 - [TaskTypeCreateRequestData](docs/TaskTypeCreateRequestData.md)
 - [TaskTypeList](docs/TaskTypeList.md)
 - [TaskTypeShow](docs/TaskTypeShow.md)
 - [TaskTypeUpdateRequest](docs/TaskTypeUpdateRequest.md)
 - [TaskTypeUpdateRequestData](docs/TaskTypeUpdateRequestData.md)
 - [TaskUpdateRequest](docs/TaskUpdateRequest.md)
 - [TaskUpdateRequestData](docs/TaskUpdateRequestData.md)
 - [TaskUpdateRequestDataAssignee](docs/TaskUpdateRequestDataAssignee.md)
 - [TextSnippet](docs/TextSnippet.md)
 - [TextSnippetBase](docs/TextSnippetBase.md)
 - [TextSnippetCreateRequest](docs/TextSnippetCreateRequest.md)
 - [TextSnippetCreateRequestData](docs/TextSnippetCreateRequestData.md)
 - [TextSnippetList](docs/TextSnippetList.md)
 - [TextSnippetShow](docs/TextSnippetShow.md)
 - [TextSnippetUpdateRequest](docs/TextSnippetUpdateRequest.md)
 - [TextSnippetUpdateRequestData](docs/TextSnippetUpdateRequestData.md)
 - [Timer](docs/Timer.md)
 - [TimerBase](docs/TimerBase.md)
 - [TimerCreateRequest](docs/TimerCreateRequest.md)
 - [TimerCreateRequestData](docs/TimerCreateRequestData.md)
 - [TimerCreateRequestDataActivity](docs/TimerCreateRequestDataActivity.md)
 - [TimerShow](docs/TimerShow.md)
 - [TrustLineItem](docs/TrustLineItem.md)
 - [TrustLineItemBase](docs/TrustLineItemBase.md)
 - [TrustLineItemList](docs/TrustLineItemList.md)
 - [TrustLineItemShow](docs/TrustLineItemShow.md)
 - [TrustLineItemUpdateRequest](docs/TrustLineItemUpdateRequest.md)
 - [TrustLineItemUpdateRequestData](docs/TrustLineItemUpdateRequestData.md)
 - [TrustRequest](docs/TrustRequest.md)
 - [TrustRequestBase](docs/TrustRequestBase.md)
 - [TrustRequestCreateRequest](docs/TrustRequestCreateRequest.md)
 - [TrustRequestCreateRequestData](docs/TrustRequestCreateRequestData.md)
 - [TrustRequestCreateRequestDataMatterInner](docs/TrustRequestCreateRequestDataMatterInner.md)
 - [TrustRequestShow](docs/TrustRequestShow.md)
 - [User](docs/User.md)
 - [UserBase](docs/UserBase.md)
 - [UserList](docs/UserList.md)
 - [UserShow](docs/UserShow.md)
 - [UtbmsCode](docs/UtbmsCode.md)
 - [UtbmsCodeBase](docs/UtbmsCodeBase.md)
 - [UtbmsCodeList](docs/UtbmsCodeList.md)
 - [UtbmsCodeShow](docs/UtbmsCodeShow.md)
 - [UtbmsSet](docs/UtbmsSet.md)
 - [UtbmsSetBase](docs/UtbmsSetBase.md)
 - [UtbmsSetList](docs/UtbmsSetList.md)
 - [WebSiteBase](docs/WebSiteBase.md)
 - [Webhook](docs/Webhook.md)
 - [WebhookBase](docs/WebhookBase.md)
 - [WebhookCreateRequest](docs/WebhookCreateRequest.md)
 - [WebhookCreateRequestData](docs/WebhookCreateRequestData.md)
 - [WebhookList](docs/WebhookList.md)
 - [WebhookShow](docs/WebhookShow.md)
 - [WebhookUpdateRequest](docs/WebhookUpdateRequest.md)
 - [WebhookUpdateRequestData](docs/WebhookUpdateRequestData.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author

api@clio.com


